% Auto-generated chapter 66 for bukhari
% Hadiths in this chapter: 87

\hadithdefcmd{bukhari}{4979}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ أَخْبَرَتْنِي عَائِشَةُ، وَابْنُ، عَبَّاسٍ رضى الله عنهم قَالاَ لَبِثَ النَّبِيُّ صلى الله عليه وسلم بِمَكَّةَ عَشْرَ سِنِينَ يُنْزَلُ عَلَيْهِ الْقُرْآنُ وَبِالْمَدِينَةِ عَشْرَ سِنِينَ\hadithno{4979}\hadithtrans{Narrated `Aisha and Ibn `Abbas:The Prophet (ﷺ) remained in Mecca for ten years, during which the Qur'an used to be revealed to him; and he stayed in Medina for ten years}}
\hadithdefcmd{bukhari}{4980}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي، عَنْ أَبِي عُثْمَانَ، قَالَ أُنْبِئْتُ أَنَّ جِبْرِيلَ، أَتَى النَّبِيَّ صلى الله عليه وسلم وَعِنْدَهُ أُمُّ سَلَمَةَ فَجَعَلَ يَتَحَدَّثُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأُمِّ سَلَمَةَ ‏ "‏ مَنْ هَذَا ‏"‏‏.‏ أَوْ كَمَا قَالَ قَالَتْ هَذَا دِحْيَةُ‏.‏ فَلَمَّا قَامَ قَالَتْ وَاللَّهِ مَا حَسِبْتُهُ إِلاَّ إِيَّاهُ حَتَّى سَمِعْتُ خُطْبَةَ النَّبِيِّ صلى الله عليه وسلم يُخْبِرُ خَبَرَ جِبْرِيلَ أَوْ كَمَا قَالَ، قَالَ أَبِي قُلْتُ لأَبِي عُثْمَانَ مِمَّنْ سَمِعْتَ هَذَا‏.‏ قَالَ مِنْ أُسَامَةَ بْنِ زَيْدٍ‏.‏\hadithno{4980}\hadithtrans{Narrated Abu `Uthman:I was informed that Gabriel came to the Prophet (ﷺ) while Um Salama was with him. Gabriel started talking (to the Prophet). Then the Prophet (ﷺ) asked Um Salama, "Who is this?" She replied, "He is Dihya (al-Kalbi)." When Gabriel had left, Um Salama said, "By Allah, I did not take him for anybody other than him (i.e. Dihya) till I heard the sermon of the Prophet (ﷺ) wherein he informed about the news of Gabriel." The subnarrator asked Abu `Uthman: From whom have you heard that? Abu `Uthman said: From Usama bin Zaid}}
\hadithdefcmd{bukhari}{4981}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا مِنَ الأَنْبِيَاءِ نَبِيٌّ إِلاَّ أُعْطِيَ مَا مِثْلُهُ آمَنَ عَلَيْهِ الْبَشَرُ، وَإِنَّمَا كَانَ الَّذِي أُوتِيتُ وَحْيًا أَوْحَاهُ اللَّهُ إِلَىَّ فَأَرْجُو أَنْ أَكُونَ أَكْثَرَهُمْ تَابِعًا يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{4981}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Every Prophet was given miracles because of which people believed, but what I have been given, is Divine Inspiration which Allah has revealed to me. So I hope that my followers will outnumber the followers of the other Prophets on the Day of Resurrection}}
\hadithdefcmd{bukhari}{4982}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّ اللَّهَ، تَعَالَى تَابَعَ عَلَى رَسُولِهِ صلى الله عليه وسلم قَبْلَ وَفَاتِهِ حَتَّى تَوَفَّاهُ أَكْثَرَ مَا كَانَ الْوَحْىُ، ثُمَّ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدُ‏.‏\hadithno{4982}\hadithtrans{Narrated Anas bin Malik:Allah sent down His Divine Inspiration to His Apostle continuously and abundantly during the period preceding his death till He took him unto Him. That was the period of the greatest part of revelation; and Allah's Messenger (ﷺ) died after that}}
\hadithdefcmd{bukhari}{4983}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ جُنْدَبًا، يَقُولُ اشْتَكَى النَّبِيُّ صلى الله عليه وسلم فَلَمْ يَقُمْ لَيْلَةً أَوْ لَيْلَتَيْنِ فَأَتَتْهُ امْرَأَةٌ فَقَالَتْ يَا مُحَمَّدُ مَا أُرَى شَيْطَانَكَ إِلاَّ قَدْ تَرَكَكَ، فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَالضُّحَى * وَاللَّيْلِ إِذَا سَجَى * مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَى‏\}‏\hadithno{4983}\hadithtrans{Narrated Jundub:Once the Prophet (ﷺ) fell ill and did not offer the night prayer (Tahajjud prayer) for a night or two. A woman (the wife of Abu Lahab) came to him and said, "O Muhammad ! I do not see but that your Satan has left you." Then Allah revealed (Surat-Ad-Duha): 'By the fore-noon, and by the night when it darkens (or is still); Your Lord has not forsaken you, nor hated you}}
\hadithdefcmd{bukhari}{4984}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، وَأَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ فَأَمَرَ عُثْمَانُ زَيْدَ بْنَ ثَابِتٍ وَسَعِيدَ بْنَ الْعَاصِ وَعَبْدَ اللَّهِ بْنَ الزُّبَيْرِ وَعَبْدَ الرَّحْمَنِ بْنَ الْحَارِثِ بْنِ هِشَامٍ أَنْ يَنْسَخُوهَا، فِي الْمَصَاحِفِ وَقَالَ لَهُمْ إِذَا اخْتَلَفْتُمْ أَنْتُمْ وَزَيْدُ بْنُ ثَابِتٍ فِي عَرَبِيَّةٍ مِنْ عَرَبِيَّةِ الْقُرْآنِ فَاكْتُبُوهَا بِلِسَانِ قُرَيْشٍ، فَإِنَّ الْقُرْآنَ أُنْزِلَ بِلِسَانِهِمْ فَفَعَلُوا‏.‏\hadithno{4984}\hadithtrans{Narrated Anas bin Malik:(The Caliph `Uthman ordered Zaid bin Thabit, Sa`id bin Al-As, `Abdullah bin Az-Zubair and `Abdur- Rahman bin Al-Harith bin Hisham to write the Qur'an in the form of a book (Mushafs) and said to them. "In case you disagree with Zaid bin Thabit (Al-Ansari) regarding any dialectic Arabic utterance of the Qur'an, then write it in the dialect of Quraish, for the Qur'an was revealed in this dialect." So they did it}}
\hadithdefcmd{bukhari}{4985}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَطَاءٌ،‏.‏ وَقَالَ مُسَدَّدٌ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، قَالَ أَخْبَرَنِي صَفْوَانُ بْنُ يَعْلَى بْنِ أُمَيَّةَ، أَنَّ يَعْلَى، كَانَ يَقُولُ لَيْتَنِي أَرَى رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ يُنْزَلُ عَلَيْهِ الْوَحْىُ، فَلَمَّا كَانَ النَّبِيُّ صلى الله عليه وسلم بِالْجِعْرَانَةِ وَعَلَيْهِ ثَوْبٌ قَدْ أَظَلَّ عَلَيْهِ وَمَعَهُ نَاسٌ مِنْ أَصْحَابِهِ إِذْ جَاءَهُ رَجُلٌ مُتَضَمِّخٌ بِطِيبٍ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي رَجُلٍ أَحْرَمَ فِي جُبَّةٍ بَعْدَ مَا تَضَمَّخَ بِطِيبٍ فَنَظَرَ النَّبِيُّ صلى الله عليه وسلم سَاعَةً فَجَاءَهُ الْوَحْىُ فَأَشَارَ عُمَرُ إِلَى يَعْلَى أَنْ تَعَالَ، فَجَاءَ يَعْلَى فَأَدْخَلَ رَأْسَهُ فَإِذَا هُوَ مُحْمَرُّ الْوَجْهِ يَغِطُّ كَذَلِكَ سَاعَةً ثُمَّ سُرِّيَ عَنْهُ فَقَالَ ‏"‏ أَيْنَ الَّذِي يَسْأَلُنِي عَنِ الْعُمْرَةِ آنِفًا ‏"‏‏.‏ فَالْتُمِسَ الرَّجُلُ فَجِيءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَمَّا الطِّيبُ الَّذِي بِكَ فَاغْسِلْهُ ثَلاَثَ مَرَّاتٍ، وَأَمَّا الْجُبَّةُ فَانْزِعْهَا ثُمَّ اصْنَعْ فِي عُمْرَتِكَ كَمَا تَصْنَعُ فِي حَجِّكَ ‏"‏‏.‏\hadithno{4985}\hadithtrans{Narrated Safwan bin Ya`la bin Umaiya:Ya`la used to say, "I wish I could see Allah's Messenger (ﷺ) at the time he is being inspired Divinely." When the Prophet (ﷺ) was at Al-Ji'rana and was shaded by a garment hanging over him and some of his companions were with him, a man perfumed with scent came and said, "O Allah's Messenger (ﷺ)! What is your opinion regarding a man who assumes Ihram and puts on a cloak after perfuming his body with scent?" The Prophet (ﷺ) waited for a while, and then the Divine Inspiration descended upon him. `Umar pointed out to Ya`la, telling him to come. Ya`la came and pushed his head (underneath the screen which was covering the Prophet (ﷺ) ) and behold! The Prophet's face was red and he kept on breathing heavily for a while and then he was relieved. Thereupon he said, "Where is the questioner who asked me about `Umra a while ago?" The man was sought and then was brought before the Prophet (ﷺ) who said (to him), "As regards the scent which you perfumed your body with, you must wash it off thrice, and as for your cloak, you must take it off; and then perform in your `Umra all those things which you perform in Hajj}}
\hadithdefcmd{bukhari}{4986}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ بْنِ السَّبَّاقِ، أَنَّ زَيْدَ بْنَ ثَابِتٍ ـ رضى الله عنه ـ قَالَ أَرْسَلَ إِلَىَّ أَبُو بَكْرٍ مَقْتَلَ أَهْلِ الْيَمَامَةِ فَإِذَا عُمَرُ بْنُ الْخَطَّابِ عِنْدَهُ قَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ إِنَّ عُمَرَ أَتَانِي فَقَالَ إِنَّ الْقَتْلَ قَدِ اسْتَحَرَّ يَوْمَ الْيَمَامَةِ بِقُرَّاءِ الْقُرْآنِ وَإِنِّي أَخْشَى أَنْ يَسْتَحِرَّ الْقَتْلُ بِالْقُرَّاءِ بِالْمَوَاطِنِ، فَيَذْهَبَ كَثِيرٌ مِنَ الْقُرْآنِ وَإِنِّي أَرَى أَنْ تَأْمُرَ بِجَمْعِ الْقُرْآنِ‏.‏ قُلْتُ لِعُمَرَ كَيْفَ تَفْعَلُ شَيْئًا لَمْ يَفْعَلْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ عُمَرُ هَذَا وَاللَّهِ خَيْرٌ‏.‏ فَلَمْ يَزَلْ عُمَرُ يُرَاجِعُنِي حَتَّى شَرَحَ اللَّهُ صَدْرِي لِذَلِكَ، وَرَأَيْتُ فِي ذَلِكَ الَّذِي رَأَى عُمَرُ‏.‏ قَالَ زَيْدٌ قَالَ أَبُو بَكْرٍ إِنَّكَ رَجُلٌ شَابٌّ عَاقِلٌ لاَ نَتَّهِمُكَ، وَقَدْ كُنْتَ تَكْتُبُ الْوَحْىَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَتَتَبَّعِ الْقُرْآنَ فَاجْمَعْهُ فَوَاللَّهِ لَوْ كَلَّفُونِي نَقْلَ جَبَلٍ مِنَ الْجِبَالِ مَا كَانَ أَثْقَلَ عَلَىَّ مِمَّا أَمَرَنِي مِنْ جَمْعِ الْقُرْآنِ قُلْتُ كَيْفَ تَفْعَلُونَ شَيْئًا لَمْ يَفْعَلْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ هُوَ وَاللَّهِ خَيْرٌ فَلَمْ يَزَلْ أَبُو بَكْرٍ يُرَاجِعُنِي حَتَّى شَرَحَ اللَّهُ صَدْرِي لِلَّذِي شَرَحَ لَهُ صَدْرَ أَبِي بَكْرٍ وَعُمَرَ ـ رضى الله عنهما ـ فَتَتَبَّعْتُ الْقُرْآنَ أَجْمَعُهُ مِنَ الْعُسُبِ وَاللِّخَافِ وَصُدُورِ الرِّجَالِ حَتَّى وَجَدْتُ آخِرَ سُورَةِ التَّوْبَةِ مَعَ أَبِي خُزَيْمَةَ الأَنْصَارِيِّ لَمْ أَجِدْهَا مَعَ أَحَدٍ غَيْرَهُ ‏\{‏لَقَدْ جَاءَكُمْ رَسُولٌ مِنْ أَنْفُسِكُمْ عَزِيزٌ عَلَيْهِ مَا عَنِتُّمْ‏\}‏ حَتَّى خَاتِمَةِ بَرَاءَةَ، فَكَانَتِ الصُّحُفُ عِنْدَ أَبِي بَكْرٍ حَتَّى تَوَفَّاهُ اللَّهُ ثُمَّ عِنْدَ عُمَرَ حَيَاتَهُ ثُمَّ عِنْدَ حَفْصَةَ بِنْتِ عُمَرَ ـ رضى الله عنه ـ‏.‏\hadithno{4986}\hadithtrans{Narrated Zaid bin Thabit:Abu Bakr As-Siddiq sent for me when the people of Yamama had been killed (i.e., a number of the Prophet's Companions who fought against Musailima). (I went to him) and found `Umar bin Al- Khattab sitting with him. Abu Bakr then said (to me), "`Umar has come to me and said: "Casualties were heavy among the Qurra' of the Qur'an (i.e. those who knew the Qur'an by heart) on the day of the Battle of Yamama, and I am afraid that more heavy casualties may take place among the Qurra' on other battlefields, whereby a large part of the Qur'an may be lost. Therefore I suggest, you (Abu Bakr) order that the Qur'an be collected." I said to `Umar, "How can you do something which Allah's Apostle did not do?" `Umar said, "By Allah, that is a good project." `Umar kept on urging me to accept his proposal till Allah opened my chest for it and I began to realize the good in the idea which `Umar had realized." Then Abu Bakr said (to me). 'You are a wise young man and we do not have any suspicion about you, and you used to write the Divine Inspiration for Allah's Messenger (ﷺ). So you should search for (the fragmentary scripts of) the Qur'an and collect it in one book." By Allah If they had ordered me to shift one of the mountains, it would not have been heavier for me than this ordering me to collect the Qur'an. Then I said to Abu Bakr, "How will you do something which Allah's Messenger (ﷺ) did not do?" Abu Bakr replied, "By Allah, it is a good project." Abu Bakr kept on urging me to accept his idea until Allah opened my chest for what He had opened the chests of Abu Bakr and `Umar. So I started looking for the Qur'an and collecting it from (what was written on) palme stalks, thin white stones and also from the men who knew it by heart, till I found the last Verse of Surat at-Tauba (Repentance) with Abi Khuzaima Al-Ansari, and I did not find it with anybody other than him. The Verse is: 'Verily there has come unto you an Apostle (Muhammad) from amongst yourselves. It grieves him that you should receive any injury or difficulty..(till the end of Surat-Baraa' (at-Tauba) (9.128-129). Then the complete manuscripts (copy) of the Qur'an remained with Abu Bakr till he died, then with `Umar till the end of his life, and then with Hafsa, the daughter of `Umar}}
\hadithdefcmd{bukhari}{4987}{حَدَّثَنَا مُوسَى، حَدَّثَنَا إِبْرَاهِيمُ، حَدَّثَنَا ابْنُ شِهَابٍ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُ أَنَّ حُذَيْفَةَ بْنَ الْيَمَانِ قَدِمَ عَلَى عُثْمَانَ وَكَانَ يُغَازِي أَهْلَ الشَّأْمِ فِي فَتْحِ إِرْمِينِيَةَ وَأَذْرَبِيجَانَ مَعَ أَهْلِ الْعِرَاقِ فَأَفْزَعَ حُذَيْفَةَ اخْتِلاَفُهُمْ فِي الْقِرَاءَةِ فَقَالَ حُذَيْفَةُ لِعُثْمَانَ يَا أَمِيرَ الْمُؤْمِنِينَ أَدْرِكْ هَذِهِ الأُمَّةَ قَبْلَ أَنْ يَخْتَلِفُوا فِي الْكِتَابِ اخْتِلاَفَ الْيَهُودِ وَالنَّصَارَى فَأَرْسَلَ عُثْمَانُ إِلَى حَفْصَةَ أَنْ أَرْسِلِي إِلَيْنَا بِالصُّحُفِ نَنْسَخُهَا فِي الْمَصَاحِفِ ثُمَّ نَرُدُّهَا إِلَيْكِ فَأَرْسَلَتْ بِهَا حَفْصَةُ إِلَى عُثْمَانَ فَأَمَرَ زَيْدَ بْنَ ثَابِتٍ وَعَبْدَ اللَّهِ بْنَ الزُّبَيْرِ وَسَعِيدَ بْنَ الْعَاصِ وَعَبْدَ الرَّحْمَنِ بْنَ الْحَارِثِ بْنِ هِشَامٍ فَنَسَخُوهَا فِي الْمَصَاحِفِ وَقَالَ عُثْمَانُ لِلرَّهْطِ الْقُرَشِيِّينَ الثَّلاَثَةِ إِذَا اخْتَلَفْتُمْ أَنْتُمْ وَزَيْدُ بْنُ ثَابِتٍ فِي شَىْءٍ مِنَ الْقُرْآنِ فَاكْتُبُوهُ بِلِسَانِ قُرَيْشٍ فَإِنَّمَا نَزَلَ بِلِسَانِهِمْ فَفَعَلُوا حَتَّى إِذَا نَسَخُوا الصُّحُفَ فِي الْمَصَاحِفِ رَدَّ عُثْمَانُ الصُّحُفَ إِلَى حَفْصَةَ وَأَرْسَلَ إِلَى كُلِّ أُفُقٍ بِمُصْحَفٍ مِمَّا نَسَخُوا وَأَمَرَ بِمَا سِوَاهُ مِنَ الْقُرْآنِ فِي كُلِّ صَحِيفَةٍ أَوْ مُصْحَفٍ أَنْ يُحْرَقَ‏.‏\hadithno{4987}\hadithtrans{Narrated Anas bin Malik:Hudhaifa bin Al-Yaman came to `Uthman at the time when the people of Sham and the people of Iraq were Waging war to conquer Arminya and Adharbijan. Hudhaifa was afraid of their (the people of Sham and Iraq) differences in the recitation of the Qur'an, so he said to `Uthman, "O chief of the Believers! Save this nation before they differ about the Book (Qur'an) as Jews and the Christians did before." So `Uthman sent a message to Hafsa saying, "Send us the manuscripts of the Qur'an so that we may compile the Qur'anic materials in perfect copies and return the manuscripts to you." Hafsa sent it to `Uthman. `Uthman then ordered Zaid bin Thabit, `Abdullah bin Az-Zubair, Sa`id bin Al-As and `AbdurRahman bin Harith bin Hisham to rewrite the manuscripts in perfect copies. `Uthman said to the three Quraishi men, "In case you disagree with Zaid bin Thabit on any point in the Qur'an, then write it in the dialect of Quraish, the Qur'an was revealed in their tongue." They did so, and when they had written many copies, `Uthman returned the original manuscripts to Hafsa. `Uthman sent to every Muslim province one copy of what they had copied, and ordered that all the other Qur'anic materials, whether written in fragmentary manuscripts or whole copies, be burnt}}
\hadithdefcmd{bukhari}{4988}{قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، سَمِعَ زَيْدَ بْنَ ثَابِتٍ، قَالَ فَقَدْتُ آيَةً مِنَ الأَحْزَابِ حِينَ نَسَخْنَا الْمُصْحَفَ قَدْ كُنْتُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهَا فَالْتَمَسْنَاهَا فَوَجَدْنَاهَا مَعَ خُزَيْمَةَ بْنِ ثَابِتٍ الأَنْصَارِيِّ ‏\{‏مِنَ الْمُؤْمِنِينَ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ‏\}‏ فَأَلْحَقْنَاهَا فِي سُورَتِهَا فِي الْمُصْحَفِ‏.‏\hadithno{4988}\hadithtrans{Zaid bin Thabit added, "A verse from Surat Ahzab was missed by me when we copied the Qur'an and I used to hear Allah's Messenger (ﷺ) reciting it. So we searched for it and found it with Khuza`ima bin Thabit Al-Ansari. (That Verse was):'Among the Believers are men who have been true in their covenant with Allah}}
\hadithdefcmd{bukhari}{4989}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ ابْنَ السَّبَّاقِ، قَالَ إِنَّ زَيْدَ بْنَ ثَابِتٍ قَالَ أَرْسَلَ إِلَىَّ أَبُو بَكْرٍ ـ رضى الله عنه ـ قَالَ إِنَّكَ كُنْتَ تَكْتُبُ الْوَحْىَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَاتَّبِعِ الْقُرْآنَ‏.‏ فَتَتَبَّعْتُ حَتَّى وَجَدْتُ آخِرَ سُورَةِ التَّوْبَةِ آيَتَيْنِ مَعَ أَبِي خُزَيْمَةَ الأَنْصَارِيِّ لَمْ أَجِدْهُمَا مَعَ أَحَدٍ غَيْرَهُ ‏\{‏لَقَدْ جَاءَكُمْ رَسُولٌ مِنْ أَنْفُسِكُمْ عَزِيزٌ عَلَيْهِ مَا عَنِتُّمْ‏\}‏ إِلَى آخِرِهِ‏.‏\hadithno{4989}\hadithtrans{Narrated Zaid bin Thabit:Abu Bakr sent for me and said, "You used to write the Divine Revelations for Allah's Messenger (ﷺ) : So you should search for (the Qur'an and collect) it." I started searching for the Qur'an till I found the last two Verses of Surat at-Tauba with Abi Khuza`ima Al-Ansari and I could not find these Verses with anybody other than him. (They were): 'Verily there has come unto you an Apostle (Muhammad) from amongst yourselves. It grieves him that you should receive any injury or difficulty}}
\hadithdefcmd{bukhari}{4990}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا نَزَلَتْ ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ‏\}‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ادْعُ لِي زَيْدًا وَلْيَجِئْ بِاللَّوْحِ وَالدَّوَاةِ وَالْكَتِفِ ـ أَوِ الْكَتِفِ وَالدَّوَاةِ ـ ثُمَّ قَالَ ‏"‏ اكْتُبْ لاَ يَسْتَوِي الْقَاعِدُونَ ‏"‏ وَخَلْفَ ظَهْرِ النَّبِيِّ صلى الله عليه وسلم عَمْرُو بْنُ أُمِّ مَكْتُومٍ الأَعْمَى قَالَ يَا رَسُولَ اللَّهِ فَمَا تَأْمُرُنِي فَإِنِّي رَجُلٌ ضَرِيرُ الْبَصَرِ فَنَزَلَتْ مَكَانَهَا ‏\{‏لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ‏\}‏ فِي سَبِيلِ اللَّهِ ‏\{‏غَيْرُ أُولِي الضَّرَرِ‏\}‏‏"‏\hadithno{4990}\hadithtrans{Narrated Al-Bara:There was revealed: 'Not equal are those believers who sit (at home) and those who strive and fight in the Cause of Allah.' (4.95) The Prophet (ﷺ) said, "Call Zaid for me and let him bring the board, the inkpot and the scapula bone (or the scapula bone and the ink pot)."' Then he said, "Write: 'Not equal are those Believers who sit..", and at that time `Amr bin Um Maktum, the blind man was sitting behind the Prophet (ﷺ) . He said, "O Allah's Apostle! What is your order For me (as regards the above Verse) as I am a blind man?" So, instead of the above Verse, the following Verse was revealed: 'Not equal are those believers who sit (at home) except those who are disabled (by injury or are blind or lame etc.) and those who strive and fight in the cause of Allah}}
\hadithdefcmd{bukhari}{4991}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَقْرَأَنِي جِبْرِيلُ عَلَى حَرْفٍ فَرَاجَعْتُهُ، فَلَمْ أَزَلْ أَسْتَزِيدُهُ وَيَزِيدُنِي حَتَّى انْتَهَى إِلَى سَبْعَةِ أَحْرُفٍ ‏"‏‏.‏\hadithno{4991}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) said, "Gabriel recited the Qur'an to me in one way. Then I requested him (to read it in another way), and continued asking him to recite it in other ways, and he recited it in several ways till he ultimately recited it in seven different ways}}
\hadithdefcmd{bukhari}{4992}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، وَعَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ الْقَارِيَّ، حَدَّثَاهُ أَنَّهُمَا، سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَمَعْتُ لِقِرَاءَتِهِ فَإِذَا هُوَ يَقْرَأُ عَلَى حُرُوفٍ كَثِيرَةٍ لَمْ يُقْرِئْنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ فَتَصَبَّرْتُ حَتَّى سَلَّمَ فَلَبَّبْتُهُ بِرِدَائِهِ فَقُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَأُ‏.‏ قَالَ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَقُلْتُ كَذَبْتَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَقْرَأَنِيهَا عَلَى غَيْرِ مَا قَرَأْتَ، فَانْطَلَقْتُ بِهِ أَقُودُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ بِسُورَةِ الْفُرْقَانِ عَلَى حُرُوفٍ لَمْ تُقْرِئْنِيهَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ اقْرَأْ يَا هِشَامُ ‏"‏‏.‏ فَقَرَأَ عَلَيْهِ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَأُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَذَلِكَ أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏‏.‏ فَقَرَأْتُ الْقِرَاءَةَ الَّتِي أَقْرَأَنِي، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَذَلِكَ أُنْزِلَتْ، إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏‏.‏\hadithno{4992}\hadithtrans{Narrated `Umar bin Al-Khattab:I heard Hisham bin Hakim reciting Surat Al-Furqan during the lifetime of Allah's Messenger (ﷺ) and I listened to his recitation and noticed that he recited in several different ways which Allah's Messenger (ﷺ) had not taught me. I was about to jump over him during his prayer, but I controlled my temper, and when he had completed his prayer, I put his upper garment around his neck and seized him by it and said, "Who taught you this Sura which I heard you reciting?" He replied, "Allah's Messenger (ﷺ) taught it to me." I said, "You have told a lie, for Allah's Messenger (ﷺ) has taught it to me in a different way from yours." So I dragged him to Allah's Messenger (ﷺ) and said (to Allah's Messenger (ﷺ)), "I heard this person reciting Surat Al-Furqan in a way which you haven't taught me!" On that Allah's Apostle said, "Release him, (O `Umar!) Recite, O Hisham!" Then he recited in the same way as I heard him reciting. Then Allah's Messenger (ﷺ) said, "It was revealed in this way," and added, "Recite, O `Umar!" I recited it as he had taught me. Allah's Messenger (ﷺ) then said, "It was revealed in this way. This Qur'an has been revealed to be recited in seven different ways, so recite of it whichever (way) is easier for you (or read as much of it as may be easy for you)}}
\hadithdefcmd{bukhari}{4993}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ وَأَخْبَرَنِي يُوسُفُ بْنُ مَاهَكَ، قَالَ إِنِّي عِنْدَ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ إِذْ جَاءَهَا عِرَاقِيٌّ فَقَالَ أَىُّ الْكَفَنِ خَيْرٌ قَالَتْ وَيْحَكَ وَمَا يَضُرُّكَ قَالَ يَا أُمَّ الْمُؤْمِنِينَ أَرِينِي مُصْحَفَكِ‏.‏ قَالَتْ لِمَ قَالَ لَعَلِّي أُوَلِّفُ الْقُرْآنَ عَلَيْهِ فَإِنَّهُ يُقْرَأُ غَيْرَ مُؤَلَّفٍ‏.‏ قَالَتْ وَمَا يَضُرُّكَ أَيَّهُ قَرَأْتَ قَبْلُ، إِنَّمَا نَزَلَ أَوَّلَ مَا نَزَلَ مِنْهُ سُورَةٌ مِنَ الْمُفَصَّلِ فِيهَا ذِكْرُ الْجَنَّةِ وَالنَّارِ حَتَّى إِذَا ثَابَ النَّاسُ إِلَى الإِسْلاَمِ نَزَلَ الْحَلاَلُ وَالْحَرَامُ، وَلَوْ نَزَلَ أَوَّلَ شَىْءٍ لاَ تَشْرَبُوا الْخَمْرَ‏.‏ لَقَالُوا لاَ نَدَعُ الْخَمْرَ أَبَدًا‏.‏ وَلَوْ نَزَلَ‏.‏ لاَ تَزْنُوا‏.‏ لَقَالُوا لاَ نَدَعُ الزِّنَا أَبَدًا‏.‏ لَقَدْ نَزَلَ بِمَكَّةَ عَلَى مُحَمَّدٍ صلى الله عليه وسلم وَإِنِّي لَجَارِيَةٌ أَلْعَبُ ‏\{‏بَلِ السَّاعَةُ مَوْعِدُهُمْ وَالسَّاعَةُ أَدْهَى وَأَمَرُّ‏\}‏ وَمَا نَزَلَتْ سُورَةُ الْبَقَرَةِ وَالنِّسَاءِ إِلاَّ وَأَنَا عِنْدَهُ‏.‏ قَالَ فَأَخْرَجَتْ لَهُ الْمُصْحَفَ فَأَمْلَتْ عَلَيْهِ آىَ السُّوَرِ‏.‏\hadithno{4993}\hadithtrans{Narrated Yusuf bin Mahk:While I was with Aisha, the mother of the Believers, a person from Iraq came and asked, "What type of shroud is the best?" `Aisha said, "May Allah be merciful to you! What does it matter?" He said, "O mother of the Believers! Show me (the copy of) your Qur'an," She said, "Why?" He said, "In order to compile and arrange the Qur'an according to it, for people recite it with its Suras not in proper order." `Aisha said, "What does it matter which part of it you read first? (Be informed) that the first thing that was revealed thereof was a Sura from Al-Mufassal, and in it was mentioned Paradise and the Fire. When the people embraced Islam, the Verses regarding legal and illegal things were revealed. If the first thing to be revealed was: 'Do not drink alcoholic drinks.' people would have said, 'We will never leave alcoholic drinks,' and if there had been revealed, 'Do not commit illegal sexual intercourse, 'they would have said, 'We will never give up illegal sexual intercourse.' While I was a young girl of playing age, the following Verse was revealed in Mecca to Muhammad: 'Nay! But the Hour is their appointed time (for their full recompense), and the Hour will be more grievous and more bitter.' (54.46) Sura Al-Baqara (The Cow) and Surat An-Nisa (The Women) were revealed while I was with him." Then `Aisha took out the copy of the Qur'an for the man and dictated to him the Verses of the Suras (in their proper order)}}
\hadithdefcmd{bukhari}{4994}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، سَمِعْتُ ابْنَ مَسْعُودٍ، يَقُولُ فِي بَنِي إِسْرَائِيلَ وَالْكَهْفِ وَمَرْيَمَ وَطَهَ وَالأَنْبِيَاءِ إِنَّهُنَّ مِنَ الْعِتَاقِ الأُوَلِ وَهُنَّ مِنْ تِلاَدِي‏.‏\hadithno{4994}\hadithtrans{Narrated `Abdullah bin Mas`ud:Surat Bani-lsrael, Al-Kahf (The Cave), Maryam, Taha, Al-Anbiya' (The prophets) are amongst my first earnings and my old property, and (in fact) they are my old property}}
\hadithdefcmd{bukhari}{4995}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، أَنْبَأَنَا أَبُو إِسْحَاقَ، سَمِعَ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ تَعَلَّمْتُ ‏\{‏سَبِّحِ اسْمَ رَبِّكَ‏\}‏ قَبْلَ أَنْ يَقْدَمَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{4995}\hadithtrans{Narrated Al-Bara':I learnt, 'Glorify the Name of your Lord the Most High' (Surat al-A'la) No 87, before the Prophet (ﷺ) came (to Medina)}}
\hadithdefcmd{bukhari}{4996}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ قَالَ عَبْدُ اللَّهِ قَدْ عَلِمْتُ النَّظَائِرَ الَّتِي كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَؤُهُنَّ اثْنَيْنِ اثْنَيْنِ فِي كُلِّ رَكْعَةٍ‏.‏ فَقَامَ عَبْدُ اللَّهِ وَدَخَلَ مَعَهُ عَلْقَمَةُ وَخَرَجَ عَلْقَمَةُ فَسَأَلْنَاهُ فَقَالَ عِشْرُونَ سُورَةً مِنْ أَوَّلِ الْمُفَصَّلِ عَلَى تَأْلِيفِ ابْنِ مَسْعُودٍ آخِرُهُنَّ الْحَوَامِيمُ حم الدُّخَانُ وَعَمَّ يَتَسَاءَلُونَ‏.‏\hadithno{4996}\hadithtrans{Narrated Shaqiq:`Abdullah said, "I learnt An-Naza'ir which the Prophet (ﷺ) used to recite in pairs in each rak`a." Then `Abdullah got up and Alqama accompanied him to his house, and when Alqama came out, we asked him (about those Suras). He said, "They are twenty Suras that start from the beginning of Al- Mufassal, according to the arrangement done be Ibn Mas`ud, and end with the Suras starting with Ha Mim, e.g. Ha Mim (the Smoke). and "About what they question one another?}}
\hadithdefcmd{bukhari}{4997}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم أَجْوَدَ النَّاسِ بِالْخَيْرِ، وَأَجْوَدُ مَا يَكُونُ فِي شَهْرِ رَمَضَانَ لأَنَّ جِبْرِيلَ كَانَ يَلْقَاهُ فِي كُلِّ لَيْلَةٍ فِي شَهْرِ رَمَضَانَ حَتَّى يَنْسَلِخَ يَعْرِضُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الْقُرْآنَ، فَإِذَا لَقِيَهُ جِبْرِيلُ كَانَ أَجْوَدَ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ‏.‏\hadithno{4997}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was the most generous person, and he used to become more so (generous) particularly in the month of Ramadan because Gabriel used to meet him every night of the month of Ramadan till it elapsed. Allah's Messenger (ﷺ) used to recite the Qur'an for him. When Gabriel met him, he used to become more generous than the fast wind in doing good}}
\hadithdefcmd{bukhari}{4998}{حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ يَعْرِضُ عَلَى النَّبِيِّ صلى الله عليه وسلم الْقُرْآنَ كُلَّ عَامٍ مَرَّةً، فَعَرَضَ عَلَيْهِ مَرَّتَيْنِ فِي الْعَامِ الَّذِي قُبِضَ، وَكَانَ يَعْتَكِفُ كُلَّ عَامٍ عَشْرًا فَاعْتَكَفَ عِشْرِينَ فِي الْعَامِ الَّذِي قُبِضَ ‏\{‏فِيهِ‏\}‏\hadithno{4998}\hadithtrans{Narrated Abu-Huraira:Gabriel used to repeat the recitation of the Qur'an with the Prophet (ﷺ) once a year, but he repeated it twice with him in the year he died. The Prophet (ﷺ) used to stay in I`tikaf for ten days every year (in the month of Ramadan), but in the year of his death, he stayed in I`tikaf for twenty days}}
\hadithdefcmd{bukhari}{4999}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، ذَكَرَ عَبْدُ اللَّهِ بْنُ عَمْرٍو عَبْدَ اللَّهِ بْنَ مَسْعُودٍ فَقَالَ لاَ أَزَالُ أُحِبُّهُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ خُذُوا الْقُرْآنَ مِنْ أَرْبَعَةٍ مِنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَسَالِمٍ وَمُعَاذٍ وَأُبَىِّ بْنِ كَعْبٍ ‏"‏‏.‏\hadithno{4999}\hadithtrans{Narrated Masriq:`Abdullah bin `Amr mentioned `Abdullah bin Masud and said, "I shall ever love that man, for I heard the Prophet (ﷺ) saying, 'Take (learn) the Qur'an from four: `Abdullah bin Masud, Salim, Mu`adh and Ubai bin Ka`b}}
\hadithdefcmd{bukhari}{5000}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا شَقِيقُ بْنُ سَلَمَةَ، قَالَ خَطَبَنَا عَبْدُ اللَّهِ فَقَالَ وَاللَّهِ لَقَدْ أَخَذْتُ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم بِضْعًا وَسَبْعِينَ سُورَةً، وَاللَّهِ لَقَدْ عَلِمَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم أَنِّي مِنْ أَعْلَمِهِمْ بِكِتَابِ اللَّهِ وَمَا أَنَا بِخَيْرِهِمْ‏.‏ قَالَ شَقِيقٌ فَجَلَسْتُ فِي الْحِلَقِ أَسْمَعُ مَا يَقُولُونَ فَمَا سَمِعْتُ رَادًّا يَقُولُ غَيْرَ ذَلِكَ‏.‏\hadithno{5000}\hadithtrans{Narrated Shaqiq bin Salama:Once `Abdullah bin Mas`ud delivered a sermon before us and said, "By Allah, I learnt over seventy Suras direct from Allah's Messenger (ﷺ) . By Allah, the companions of the Prophet (ﷺ) came to know that I am one of those who know Allah's Book best of all of them, yet I am not the best of them." Shaqiq added: I sat in his religious gathering and I did not hear anybody opposing him (in his speech)}}
\hadithdefcmd{bukhari}{5001}{حَدَّثَنِي مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ كُنَّا بِحِمْصَ فَقَرَأَ ابْنُ مَسْعُودٍ سُورَةَ يُوسُفَ، فَقَالَ رَجُلٌ مَا هَكَذَا أُنْزِلَتْ قَالَ قَرَأْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحْسَنْتَ‏.‏ وَوَجَدَ مِنْهُ رِيحَ الْخَمْرِ فَقَالَ أَتَجْمَعُ أَنْ تُكَذِّبَ بِكِتَابِ اللَّهِ وَتَشْرَبَ الْخَمْرَ‏.‏ فَضَرَبَهُ الْحَدَّ‏.‏\hadithno{5001}\hadithtrans{Narrated 'Alqama:While we were in the city of Hims (in Syria), Ibn Mas`ud recited Surat Yusuf. A man said to him), "It was not revealed in this way." Then Ibn Mas`ud said, "I recited it in this way before Allah's Messenger (ﷺ) and he confirmed my recitation by saying, 'Well done!' " Ibn Mas`ud detected the smell of wine from the man's mouth, so he said to him, "Aren't you ashamed of telling a lie about Allah's Book and (along with this) you drink alcoholic liquors too?" Then he lashed him according to the law}}
\hadithdefcmd{bukhari}{5002}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا مُسْلِمٌ، عَنْ مَسْرُوقٍ، قَالَ قَالَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ وَاللَّهِ الَّذِي لاَ إِلَهَ غَيْرُهُ مَا أُنْزِلَتْ سُورَةٌ مِنْ كِتَابِ اللَّهِ إِلاَّ أَنَا أَعْلَمُ أَيْنَ أُنْزِلَتْ وَلاَ أُنْزِلَتْ آيَةٌ مِنْ كِتَابِ اللَّهِ إِلاَّ أَنَا أَعْلَمُ فِيمَ أُنْزِلَتْ، وَلَوْ أَعْلَمُ أَحَدًا أَعْلَمَ مِنِّي بِكِتَابِ اللَّهِ تُبَلِّغُهُ الإِبِلُ لَرَكِبْتُ إِلَيْهِ‏.‏\hadithno{5002}\hadithtrans{Narrated `Abdullah (bin Mas`ud):By Allah other than Whom none has the right to be worshipped! There is no Sura revealed in Allah's Book but I know at what place it was revealed; and there is no Verse revealed in Allah's Book but I know about whom it was revealed. And if I know that there is somebody who knows Allah's Book better than I, and he is at a place that camels can reach, I would go to him}}
\hadithdefcmd{bukhari}{5003}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ مَنْ جَمَعَ الْقُرْآنَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم قَالَ أَرْبَعَةٌ كُلُّهُمْ مِنَ الأَنْصَارِ أُبَىُّ بْنُ كَعْبٍ وَمُعَاذُ بْنُ جَبَلٍ، وَزَيْدُ بْنُ ثَابِتٍ، وَأَبُو زَيْدٍ‏.‏ تَابَعَهُ الْفَضْلُ عَنْ حُسَيْنِ بْنِ وَاقِدٍ عَنْ ثُمَامَةَ عَنْ أَنَسٍ‏.‏\hadithno{5003}\hadithtrans{Narrated Qatada:I asked Anas bin Malik: "Who collected the Qur'an at the time of the Prophet (ﷺ) ?" He replied, "Four, all of whom were from the Ansar: Ubai bin Ka`b, Mu`adh bin Jabal, Zaid bin Thabit and Abu Zaid}}
\hadithdefcmd{bukhari}{5004}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي ثَابِتٌ الْبُنَانِيُّ، وَثُمَامَةُ، عَنْ أَنَسٍ، قَالَ مَاتَ النَّبِيُّ صلى الله عليه وسلم وَلَمْ يَجْمَعِ الْقُرْآنَ غَيْرُ أَرْبَعَةٍ أَبُو الدَّرْدَاءِ وَمُعَاذُ بْنُ جَبَلٍ وَزَيْدُ بْنُ ثَابِتٍ وَأَبُو زَيْدٍ‏.‏ قَالَ وَنَحْنُ وَرِثْنَاهُ‏.‏\hadithno{5004}\hadithtrans{Narrated Anas bin Malik:When the Prophet (ﷺ) died, none had collected the Qur'an but four persons;: Abu Ad-Darda'. Mu`adh bin Jabal, Zaid bin Thabit and Abu Zaid. We were the inheritor (of Abu Zaid) as he had no offspring}}
\hadithdefcmd{bukhari}{5005}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ عُمَرُ أُبَىٌّ أَقْرَؤُنَا وَإِنَّا لَنَدَعُ مِنْ لَحَنِ أُبَىٍّ، وَأُبَىٌّ يَقُولُ أَخَذْتُهُ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ أَتْرُكُهُ لِشَىْءٍ قَالَ اللَّهُ تَعَالَى ‏\{‏مَا نَنْسَخْ مِنْ آيَةٍ أَوْ نَنْسَأْهَا نَأْتِ بِخَيْرٍ مِنْهَا أَوْ مِثْلِهَا‏\}‏\hadithno{5005}\hadithtrans{Narrated Ibn `Abbas:`Umar said, Ubai was the best of us in the recitation (of the Qur'an) yet we leave some of what he recites.' Ubai says, 'PI have taken it from the mouth of Allah's Messenger (ﷺ) and will not leave for anything whatever." But Allah said "None of Our Revelations do We abrogate or cause to be forgotten but We substitute something better or similar}}
\hadithdefcmd{bukhari}{5006}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، قَالَ كُنْتُ أُصَلِّي فَدَعَانِي النَّبِيُّ صلى الله عليه وسلم فَلَمْ أُجِبْهُ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أُصَلِّي‏.‏ قَالَ ‏"‏ أَلَمْ يَقُلِ اللَّهُ ‏\{‏اسْتَجِيبُوا لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ‏\}‏ ثُمَّ قَالَ أَلاَ أُعَلِّمُكَ أَعْظَمَ سُورَةٍ فِي الْقُرْآنِ قَبْلَ أَنْ تَخْرُجَ مِنَ الْمَسْجِدِ ‏"‏‏.‏ فَأَخَذَ بِيَدِي فَلَمَّا أَرَدْنَا أَنْ نَخْرُجَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ قُلْتَ لأُعَلِّمَنَّكَ أَعْظَمَ سُورَةٍ مِنَ الْقُرْآنِ‏.‏ قَالَ ‏"‏‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ هِيَ السَّبْعُ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ الَّذِي أُوتِيتُهُ ‏"‏‏.‏\hadithno{5006}\hadithtrans{Narrated Abu Sa`id Al-Mu'alla:While I was praying, the Prophet (ﷺ) called me but I did not respond to his call. Later I said, "O Allah's Apostle! I was praying." He said, "Didn't Allah say: 'O you who believe! Give your response to Allah (by obeying Him) and to His Apostle when he calls you'?" (8.24) He then said, "Shall I not teach you the most superior Surah in the Qur'an?" He said, '(It is), 'Praise be to Allah, the Lord of the worlds. ' (i.e., Surat Al-Fatiha) which consists of seven repeatedly recited Verses and the Magnificent Qur'an which was given to me}}
\hadithdefcmd{bukhari}{5007}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبٌ، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ مَعْبَدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا فِي مَسِيرٍ لَنَا فَنَزَلْنَا فَجَاءَتْ جَارِيَةٌ فَقَالَتْ إِنَّ سَيِّدَ الْحَىِّ سَلِيمٌ، وَإِنَّ نَفَرَنَا غُيَّبٌ فَهَلْ مِنْكُمْ رَاقٍ فَقَامَ مَعَهَا رَجُلٌ مَا كُنَّا نَأْبُنُهُ بِرُقْيَةٍ فَرَقَاهُ فَبَرَأَ فَأَمَرَ لَهُ بِثَلاَثِينَ شَاةً وَسَقَانَا لَبَنًا فَلَمَّا رَجَعَ قُلْنَا لَهُ أَكُنْتَ تُحْسِنُ رُقْيَةً أَوْ كُنْتَ تَرْقِي قَالَ لاَ مَا رَقَيْتُ إِلاَّ بِأُمِّ الْكِتَابِ‏.‏ قُلْنَا لاَ تُحْدِثُوا شَيْئًا حَتَّى نَأْتِيَ ـ أَوْ نَسْأَلَ ـ النَّبِيَّ صلى الله عليه وسلم فَلَمَّا قَدِمْنَا الْمَدِينَةَ ذَكَرْنَاهُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ وَمَا كَانَ يُدْرِيهِ أَنَّهَا رُقْيَةٌ اقْسِمُوا وَاضْرِبُوا لِي بِسَهْمٍ ‏"‏‏.‏ وَقَالَ أَبُو مَعْمَرٍ حَدَّثَنَا عَبْدُ الْوَارِثِ حَدَّثَنَا هِشَامٌ حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ حَدَّثَنِي مَعْبَدُ بْنُ سِيرِينَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ بِهَذَا\hadithno{5007}\hadithtrans{Narrated Abu Sa`id Al-Khudri:While we were on one of our journeys, we dismounted at a place where a slave girl came and said, "The chief of this tribe has been stung by a scorpion and our men are not present; is there anybody among you who can treat him (by reciting something)?" Then one of our men went along with her though we did not think that he knew any such treatment. But he treated the chief by reciting something, and the sick man recovered whereupon he gave him thirty sheep and gave us milk to drink (as a reward). When he returned, we asked our friend, "Did you know how to treat with the recitation of something?" He said, "No, but I treated him only with the recitation of the Mother of the Book (i.e., Al-Fatiha)." We said, "Do not say anything (about it) till we reach or ask the Prophet (ﷺ) so when we reached Medina, we mentioned that to the Prophet (in order to know whether the sheep which we had taken were lawful to take or not). The Prophet (ﷺ) said, "How did he come to know that it (Al-Fatiha) could be used for treatment? Distribute your reward and assign for me one share thereof as well}}
\hadithdefcmd{bukhari}{5008}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ مَنْ قَرَأَ بِالآيَتَيْنِ‏.‏ ‏.‏‏.‏ ‏.‏\hadithno{5008}\hadithtrans{Narrated Abu Mas'ud:Whoever recites two verses ... (text as in the following hadith)}}
\hadithdefcmd{bukhari}{5009}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ بِالآيَتَيْنِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي لَيْلَةٍ كَفَتَاهُ‏"‏‏.‏\hadithno{5009}\hadithtrans{Narrated Abu Mas'ud: The Prophet (ﷺ) said, "If somebody recited the last two Verses of Surat Al-Baqara at night, that will be sufficient for him}}
\hadithdefcmd{bukhari}{5010}{وَقَالَ عُثْمَانُ بْنُ الْهَيْثَمِ حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ وَكَّلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِحِفْظِ زَكَاةِ رَمَضَانَ فَأَتَانِي آتٍ فَجَعَلَ يَحْثُو مِنَ الطَّعَامِ فَأَخَذْتُهُ فَقُلْتُ لأَرْفَعَنَّكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَصَّ الْحَدِيثَ فَقَالَ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَاقْرَأْ آيَةَ الْكُرْسِيِّ لَنْ يَزَالَ مَعَكَ مِنَ اللَّهِ حَافِظٌ وَلاَ يَقْرَبُكَ شَيْطَانٌ حَتَّى تُصْبِحَ‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ صَدَقَكَ وَهْوَ كَذُوبٌ ذَاكَ شَيْطَانٌ ‏"‏‏.‏\hadithno{5010}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) ordered me to guard the Zakat revenue of Ramadan. Then somebody came to me and started stealing from the foodstuff. I caught him and said, "I will take you to Allah's Messenger (ﷺ)!" Then Abu Huraira described the whole narration and said: That person said (to me), "(Please don't take me to Allah's Messenger (ﷺ) and I will tell you a few words by which Allah will benefit you.) When you go to your bed, recite Ayat-al-Kursi, (2.255) for then there will be a guard from Allah who will protect you all night long, and Satan will not be able to come near you till dawn." (When the Prophet (ﷺ) heard the story) he said (to me), "He (who came to you at night) told you the truth although he is a liar; and it was Satan}}
\hadithdefcmd{bukhari}{5011}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانَ رَجُلٌ يَقْرَأُ سُورَةَ الْكَهْفِ وَإِلَى جَانِبِهِ حِصَانٌ مَرْبُوطٌ بِشَطَنَيْنِ فَتَغَشَّتْهُ سَحَابَةٌ فَجَعَلَتْ تَدْنُو وَتَدْنُو وَجَعَلَ فَرَسُهُ يَنْفِرُ فَلَمَّا أَصْبَحَ أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ تِلْكَ السَّكِينَةُ تَنَزَّلَتْ بِالْقُرْآنِ ‏"‏‏.‏\hadithno{5011}\hadithtrans{Narrated Al-Bara':A man was reciting Surat Al-Kahf and his horse was tied with two ropes beside him. A cloud came down and spread over that man, and it kept on coming closer and closer to him till his horse started jumping (as if afraid of something). When it was morning, the man came to the Prophet, and told him of that experience. The Prophet (ﷺ) said, "That was As-Sakina (tranquility) which descended because of (the recitation of) the Qur'an}}
\hadithdefcmd{bukhari}{5012}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسِيرُ فِي بَعْضِ أَسْفَارِهِ وَعُمَرُ بْنُ الْخَطَّابِ يَسِيرُ مَعَهُ لَيْلاً فَسَأَلَهُ عُمَرُ عَنْ شَىْءٍ فَلَمْ يُجِبْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ سَأَلَهُ فَلَمْ يُجِبْهُ ثُمَّ سَأَلَهُ فَلَمْ يُجِبْهُ، فَقَالَ عُمَرُ ثَكِلَتْكَ أُمُّكَ نَزَرْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم ثَلاَثَ مَرَّاتٍ كُلَّ ذَلِكَ لاَ يُجِيبُكَ، قَالَ عُمَرُ فَحَرَّكْتُ بَعِيرِي حَتَّى كُنْتُ أَمَامَ النَّاسِ وَخَشِيتُ أَنْ يَنْزِلَ فِيَّ قُرْآنٌ فَمَا نَشِبْتُ أَنْ سَمِعْتُ صَارِخًا يَصْرُخُ ـ قَالَ ـ فَقُلْتُ لَقَدْ خَشِيتُ أَنْ يَكُونَ نَزَلَ فِيَّ قُرْآنٌ ـ قَالَ ـ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ فَقَالَ ‏"‏ لَقَدْ أُنْزِلَتْ عَلَىَّ اللَّيْلَةَ سُورَةٌ لَهِيَ أَحَبُّ إِلَىَّ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏إِنَّا فَتَحْنَا لَكَ فَتْحًا مُبِينًا‏\}‏\hadithno{5012}\hadithtrans{Narrated Aslam:Allah's Messenger (ﷺ) was traveling on one of his journeys, and `Umar bin Al-Khattab was traveling along with him at night. `Umar asked him about something, but Allah's Messenger (ﷺ) did not answer him. He asked again, but he did not answer. He asked for the third time, but he did not answer. On that, `Umar said to himself, "May your mother lose you! You have asked Allah's Messenger (ﷺ) three times, but he did not answer at all!" `Umar said, "So I made my camel go fast till I was ahead of the people, and I was afraid that something might be revealed about me. After a little while I heard a call maker calling me, I said, 'I was afraid that some Qur'anic Verse might be revealed about me.' So I went to Allah's Apostle and greeted him. He said, 'Tonight there has been revealed to me a Surah which is dearer to me than that on which the sun shines (i.e. the world).' Then he recited: 'Verily! We have given you (O Muhammad), a manifest victory.' " (Surat al-Fath) No}}
\hadithdefcmd{bukhari}{5013}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، سَمِعَ رَجُلاً، يَقْرَأُ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ يُرَدِّدُهَا فَلَمَّا أَصْبَحَ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ وَكَأَنَّ الرَّجُلَ يَتَقَالُّهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَتَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5013}\hadithtrans{Narrated Abu Said Al-Khudri: A man heard another man reciting (Surat-Al-Ikhlas) 'Say He is Allah, (the) One.' (112. 1) repeatedly. The next morning he came to Allah's Messenger (ﷺ) and informed him about it as if he thought that it was not enough to recite. On that Allah's Messenger (ﷺ) said, "By Him in Whose Hand my life is, this Surah is equal to one-third of the Qur'an}}
\hadithdefcmd{bukhari}{5014}{وَزَادَ أَبُو مَعْمَرٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَخْبَرَنِي أَخِي، قَتَادَةُ بْنُ النُّعْمَانِ أَنَّ رَجُلاً، قَامَ فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم يَقْرَأُ مِنَ السَّحَرِ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ لاَ يَزِيدُ عَلَيْهَا، فَلَمَّا أَصْبَحْنَا أَتَى رَجُلٌ النَّبِيَّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{5014}\hadithtrans{Narrated Abu Said Al-Khudri:My brother, Qatada bin An-Nau'man said, "A man performed the night prayer late at night in the lifetime of the Prophet (ﷺ) and he read: 'Say: He is Allah, (the) One,' (112.1) and read nothing besides that. The next morning a man went to the Prophet (ﷺ) ,\textasciitilde{} and told him about that . (The Prophet (ﷺ) replied the same as (in Hadith 532) above}}
\hadithdefcmd{bukhari}{5015}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا إِبْرَاهِيمُ، وَالضَّحَّاكُ الْمَشْرِقِيُّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، رضى الله عنه قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ أَيَعْجِزُ أَحَدُكُمْ أَنْ يَقْرَأَ ثُلُثَ الْقُرْآنِ فِي لَيْلَةٍ ‏"‏‏.‏ فَشَقَّ ذَلِكَ عَلَيْهِمْ وَقَالُوا أَيُّنَا يُطِيقُ ذَلِكَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ اللَّهُ الْوَاحِدُ الصَّمَدُ ثُلُثُ الْقُرْآنِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ عَنْ إِبْرَاهِيمَ مُرْسَلٌ وَعَنِ الضَّحَّاكِ الْمَشْرِقِيِّ مُسْنَدٌ‏.‏\hadithno{5015}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said to his companions, "Is it difficult for any of you to recite one third of the Qur'an in one night?" This suggestion was difficult for them so they said, "Who among us has the power to do so, O Allah's Messenger (ﷺ)?" Allah's Apostle replied: " Allah (the) One, the Self-Sufficient Master Whom all creatures need.' (Surat Al-Ikhlas 112.1--to the End) is equal to one third of the Qur'an}}
\hadithdefcmd{bukhari}{5016}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اشْتَكَى يَقْرَأُ عَلَى نَفْسِهِ بِالْمُعَوِّذَاتِ وَيَنْفُثُ، فَلَمَّا اشْتَدَّ وَجَعُهُ كُنْتُ أَقْرَأُ عَلَيْهِ وَأَمْسَحُ بِيَدِهِ رَجَاءَ بَرَكَتِهَا‏.‏\hadithno{5016}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) became sick, he would recite Mu'awwidhat (Surat Al-Falaq and Surat An- Nas) and then blow his breath over his body. When he became seriously ill, I used to recite (these two Suras) and rub his hands over his body hoping for its blessings}}
\hadithdefcmd{bukhari}{5017}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُفَضَّلُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ كُلَّ لَيْلَةٍ جَمَعَ كَفَّيْهِ ثُمَّ نَفَثَ فِيهِمَا فَقَرَأَ فِيهِمَا ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ وَ‏\{‏قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ‏\}‏ وَ‏\{‏قُلْ أَعُوذُ بِرَبِّ النَّاسِ‏\}‏ ثُمَّ يَمْسَحُ بِهِمَا مَا اسْتَطَاعَ مِنْ جَسَدِهِ يَبْدَأُ بِهِمَا عَلَى رَأْسِهِ وَوَجْهِهِ وَمَا أَقْبَلَ مِنْ جَسَدِهِ يَفْعَلُ ذَلِكَ ثَلاَثَ مَرَّاتٍ‏.‏\hadithno{5017}\hadithtrans{Narrated 'Aisha: Whenever the Prophet (ﷺ) went to bed every night, he used to cup his hands together and blow over it after reciting Surat Al-Ikhlas, Surat Al-Falaq and Surat An-Nas, and then rub his hands over whatever parts of his body he was able to rub, starting with his head, face and front of his body. He used to do that three times}}
\hadithdefcmd{bukhari}{5018}{وَقَالَ اللَّيْثُ حَدَّثَنِي يَزِيدُ بْنُ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، قَالَ بَيْنَمَا هُوَ يَقْرَأُ مِنَ اللَّيْلِ سُورَةَ الْبَقَرَةِ وَفَرَسُهُ مَرْبُوطٌ عِنْدَهُ إِذْ جَالَتِ الْفَرَسُ فَسَكَتَ فَسَكَتَتْ فَقَرَأَ فَجَالَتِ الْفَرَسُ، فَسَكَتَ وَسَكَتَتِ الْفَرَسُ ثُمَّ قَرَأَ فَجَالَتِ الْفَرَسُ، فَانْصَرَفَ وَكَانَ ابْنُهُ يَحْيَى قَرِيبًا مِنْهَا فَأَشْفَقَ أَنْ تُصِيبَهُ فَلَمَّا اجْتَرَّهُ رَفَعَ رَأْسَهُ إِلَى السَّمَاءِ حَتَّى مَا يَرَاهَا فَلَمَّا أَصْبَحَ حَدَّثَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ اقْرَأْ يَا ابْنَ حُضَيْرٍ اقْرَأْ يَا ابْنَ حُضَيْرٍ ‏"‏‏.‏ قَالَ فَأَشْفَقْتُ يَا رَسُولَ اللَّهِ أَنْ تَطَأَ يَحْيَى وَكَانَ مِنْهَا قَرِيبًا فَرَفَعْتُ رَأْسِي فَانْصَرَفْتُ إِلَيْهِ فَرَفَعْتُ رَأْسِي إِلَى السَّمَاءِ فَإِذَا مِثْلُ الظُّلَّةِ فِيهَا أَمْثَالُ الْمَصَابِيحِ فَخَرَجَتْ حَتَّى لاَ أَرَاهَا‏.‏ قَالَ ‏"‏ وَتَدْرِي مَا ذَاكَ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ تِلْكَ الْمَلاَئِكَةُ دَنَتْ لِصَوْتِكَ وَلَوْ قَرَأْتَ لأَصْبَحَتْ يَنْظُرُ النَّاسُ إِلَيْهَا لاَ تَتَوَارَى مِنْهُمْ ‏"‏‏.‏ قَالَ ابْنُ الْهَادِ وَحَدَّثَنِي هَذَا الْحَدِيثَ عَبْدُ اللَّهِ بْنُ خَبَّابٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ عَنْ أُسَيْدِ بْنِ حُضَيْرٍ‏.‏\hadithno{5018}\hadithtrans{Narrated Usaid bin Hudair: That while he was reciting Surat Al-Baqara (The Cow) at night, and his horse was tied beside him, the horse was suddenly startled and troubled. When he stopped reciting, the horse became quiet, and when he started again, the horse was startled again. Then he stopped reciting and the horse became quiet too. He started reciting again and the horse was startled and troubled once again. Then he stopped reciting and his son, Yahya was beside the horse. He was afraid that the horse might trample on him. When he took the boy away and looked towards the sky, he could not see it. The next morning he informed the Prophet who said, "Recite, O Ibn Hudair! Recite, O Ibn Hudair!" Ibn Hudair replied, "O Allah's Messenger (ﷺ)! My son, Yahya was near the horse and I was afraid that it might trample on him, so I looked towards the sky, and went to him. When I looked at the sky, I saw something like a cloud containing what looked like lamps, so I went out in order not to see it." The Prophet (ﷺ) said, "Do you know what that was?" Ibn Hudair replied, "No." The Prophet (ﷺ) said, "Those were Angels who came near to you for your voice and if you had kept on reciting till dawn, it would have remained there till morning when people would have seen it as it would not have disappeared}}
\hadithdefcmd{bukhari}{5019}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ دَخَلْتُ أَنَا وَشَدَّادُ بْنُ مَعْقِلٍ، عَلَى ابْنِ عَبَّاسٍ رضى الله عنهما فَقَالَ لَهُ شَدَّادُ بْنُ مَعْقِلٍ أَتَرَكَ النَّبِيُّ صلى الله عليه وسلم مِنْ شَىْءٍ قَالَ مَا تَرَكَ إِلاَّ مَا بَيْنَ الدَّفَّتَيْنِ‏.‏ قَالَ وَدَخَلْنَا عَلَى مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ فَسَأَلْنَاهُ فَقَالَ مَا تَرَكَ إِلاَّ مَا بَيْنَ الدَّفَّتَيْنِ‏.‏\hadithno{5019}\hadithtrans{Narrated `Abdul `Aziz bin Rufai':Shaddad bin Ma'qil and I entered upon Ibn `Abbas. Shaddad bin Ma'qil asked him, "Did the Prophet (ﷺ) leave anything (besides the Qur'an)?" He replied. "He did not leave anything except what is Between the two bindings (of the Qur'an)." Then we visited Muhammad bin Al-Hanafiyya and asked him (the same question). He replied, "The Prophet (ﷺ) did not leave except what is between the bindings (of the Qur'an)}}
\hadithdefcmd{bukhari}{5020}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ أَبُو خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسٌ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الَّذِي يَقْرَأُ الْقُرْآنَ كَالأُتْرُجَّةِ طَعْمُهَا طَيِّبٌ وَرِيحُهَا طَيِّبٌ وَالَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَالتَّمْرَةِ طَعْمُهَا طَيِّبٌ وَلاَ رِيحَ لَهَا، وَمَثَلُ الْفَاجِرِ الَّذِي يَقْرَأُ الْقُرْآنَ كَمَثَلِ الرَّيْحَانَةِ رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ، وَمَثَلُ الْفَاجِرِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ الْحَنْظَلَةِ طَعْمُهَا مُرٌّ وَلاَ رِيحَ لَهَا ‏"‏‏.‏\hadithno{5020}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "The example of him (a believer) who recites the Qur'an is like that of a citron which tastes good and smells good. And he (a believer) who does not recite the Qur'an is like a date which is good in taste but has no smell. And the example of a dissolute wicked person who recites the Qur'an is like the Raihana (sweet basil) which smells good but tastes bitter. And the example of a dissolute wicked person who does not recite the Qur'an is like the colocynth which tastes bitter and has no smell}}
\hadithdefcmd{bukhari}{5021}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا أَجَلُكُمْ فِي أَجَلِ مَنْ خَلاَ مِنَ الأُمَمِ كَمَا بَيْنَ صَلاَةِ الْعَصْرِ وَمَغْرِبِ الشَّمْسِ، وَمَثَلُكُمْ وَمَثَلُ الْيَهُودِ وَالنَّصَارَى كَمَثَلِ رَجُلٍ اسْتَعْمَلَ عُمَّالاً، فَقَالَ مَنْ يَعْمَلُ لِي إِلَى نِصْفِ النَّهَارِ عَلَى قِيرَاطٍ فَعَمِلَتِ الْيَهُودُ فَقَالَ مَنْ يَعْمَلُ لِي مِنْ نِصْفِ النَّهَارِ إِلَى الْعَصْرِ فَعَمِلَتِ النَّصَارَى، ثُمَّ أَنْتُمْ تَعْمَلُونَ مِنَ الْعَصْرِ إِلَى الْمَغْرِبِ بِقِيرَاطَيْنِ قِيرَاطَيْنِ، قَالُوا نَحْنُ أَكْثَرُ عَمَلاً وَأَقَلُّ عَطَاءً، قَالَ هَلْ ظَلَمْتُكُمْ مِنْ حَقِّكُمْ قَالُوا لاَ قَالَ فَذَاكَ فَضْلِي أُوتِيهِ مَنْ شِئْتُ ‏"‏‏.‏\hadithno{5021}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Your life in comparison to the lifetime of the past nations is like the period between the time of `Asr prayer and sunset. Your example and the example of the Jews and Christians is that of person who employed laborers and said to them, "Who will work for me till the middle of the day for one Qirat (a special weight)?' The Jews did. He then said, "Who will work for me from the middle of the day till the `Asr prayer for one Qirat each?" The Christians worked accordingly. Then you (Muslims) are working from the `Asr prayer till the Maghrib prayer for two Qirats each. They (the Jews and the Christians) said, 'We did more labor but took less wages.' He (Allah) said, 'Have I wronged you in your rights?' They replied, 'No.' Then He said, 'This is My Blessing which I give to whom I wish}}
\hadithdefcmd{bukhari}{5022}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، حَدَّثَنَا طَلْحَةُ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى أَوْصَى النَّبِيُّ صلى الله عليه وسلم فَقَالَ لاَ‏.‏ فَقُلْتُ كَيْفَ كُتِبَ عَلَى النَّاسِ الْوَصِيَّةُ، أُمِرُوا بِهَا وَلَمْ يُوصِ قَالَ أَوْصَى بِكِتَابِ اللَّهِ‏.‏\hadithno{5022}\hadithtrans{Narrated Talha:I asked `Abdullah bin Abi `Aufa, "Did the Prophet (ﷺ) make a will (to appoint his successor or bequeath wealth)?" He replied, "No." I said, "How is it prescribed then for the people to make wills, and they are ordered to do so while the Prophet (ﷺ) did not make any will?" He said, "He made a will wherein he recommended Allah's Book}}
\hadithdefcmd{bukhari}{5023}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَمْ يَأْذَنِ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِلنَّبِيِّ صلى الله عليه وسلم يَتَغَنَّى بِالْقُرْآنِ ‏"‏‏.‏ وَقَالَ صَاحِبٌ لَهُ يُرِيدُ يَجْهَرُ بِهِ‏.‏\hadithno{5023}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah does not listen to a prophet as He listens to a prophet who recites the Qur'an in a pleasant tone." The companion of the sub-narrator (Abu Salama) said, "It means, reciting it aloud}}
\hadithdefcmd{bukhari}{5024}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِلنَّبِيِّ أَنْ يَتَغَنَّى بِالْقُرْآنِ ‏"‏‏.‏ قَالَ سُفْيَانُ تَفْسِيرُهُ يَسْتَغْنِي بِهِ‏.‏\hadithno{5024}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah does not listen to a prophet as He listens to a prophet who recites the Qur'an in a loud and pleasant tone." Sufyan said, "This saying means: a prophet who regards the Qur'an as something that makes him dispense with many worldly pleasures}}
\hadithdefcmd{bukhari}{5025}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ حَسَدَ إِلاَّ عَلَى اثْنَتَيْنِ، رَجُلٌ آتَاهُ اللَّهُ الْكِتَابَ وَقَامَ بِهِ آنَاءَ اللَّيْلِ، وَرَجُلٌ أَعْطَاهُ اللَّهُ مَالاً فَهْوَ يَتَصَدَّقُ بِهِ آنَاءَ اللَّيْلِ وَالنَّهَارِ ‏"‏‏.‏\hadithno{5025}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Not to wish to be the like except of two men. A man whom Allah has given the knowledge of the Book and he recites it during the hours of the night, and a man whom Allah has given wealth, and he spends it in charity during the night and the hours of the day}}
\hadithdefcmd{bukhari}{5026}{حَدَّثَنَا عَلِيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، سَمِعْتُ ذَكْوَانَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ عَلَّمَهُ اللَّهُ الْقُرْآنَ فَهُوَ يَتْلُوهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ فَسَمِعَهُ جَارٌ لَهُ فَقَالَ لَيْتَنِي أُوتِيتُ مِثْلَ مَا أُوتِيَ فُلاَنٌ فَعَمِلْتُ مِثْلَ مَا يَعْمَلُ، وَرَجُلٌ آتَاهُ اللَّهُ مَالاً فَهْوَ يُهْلِكُهُ فِي الْحَقِّ فَقَالَ رَجُلٌ لَيْتَنِي أُوتِيتُ مِثْلَ مَا أُوتِيَ فُلاَنٌ فَعَمِلْتُ مِثْلَ مَا يَعْمَلُ ‏"‏‏.‏\hadithno{5026}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Not to wish to be the like of except two men: A man whom Allah has taught the Qur'an and he recites it during the hours of the night and during the hours of the day, and his neighbor listens to him and says, 'I wish I had been given what has been given to so-and-so, so that I might do what he does; and a man whom Allah has given wealth and he spends it on what is just and right, whereupon an other man May say, 'I wish I had been given what so-and-so has been given, for then I would do what he does}}
\hadithdefcmd{bukhari}{5027}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَلْقَمَةُ بْنُ مَرْثَدٍ، سَمِعْتُ سَعْدَ بْنَ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عُثْمَانَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏‏.‏ قَالَ وَأَقْرَأَ أَبُو عَبْدِ الرَّحْمَنِ فِي إِمْرَةِ عُثْمَانَ حَتَّى كَانَ الْحَجَّاجُ، قَالَ وَذَاكَ الَّذِي أَقْعَدَنِي مَقْعَدِي هَذَا‏.‏\hadithno{5027}\hadithtrans{Narrated `Uthman:The Prophet (ﷺ) said, "The best among you (Muslims) are those who learn the Qur'an and teach it}}
\hadithdefcmd{bukhari}{5028}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ أَفْضَلَكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏‏.‏\hadithno{5028}\hadithtrans{Narrated `Uthman bin `Affan:The Prophet (ﷺ) said, "The most superior among you (Muslims) are those who learn the Qur'an and teach it}}
\hadithdefcmd{bukhari}{5029}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ أَتَتِ النَّبِيَّ صلى الله عليه وسلم امْرَأَةٌ فَقَالَتْ إِنَّهَا قَدْ وَهَبَتْ نَفْسَهَا لِلَّهِ وَلِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا لِي فِي النِّسَاءِ مِنْ حَاجَةٍ ‏"‏‏.‏ فَقَالَ رَجُلٌ زَوِّجْنِيهَا‏.‏ قَالَ ‏"‏ أَعْطِهَا ثَوْبًا ‏"‏‏.‏ قَالَ لاَ أَجِدُ‏.‏ قَالَ ‏"‏ أَعْطِهَا وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَاعْتَلَّ لَهُ‏.‏ فَقَالَ ‏"‏ مَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ قَالَ كَذَا وَكَذَا‏.‏ قَالَ ‏"‏ فَقَدْ زَوَّجْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5029}\hadithtrans{Narrated Sahl bin Sa`d:A lady came to the Prophet (ﷺ) and declared that she had decided to offer herself to Allah and His Apostle. The Prophet (ﷺ) said, "I am not in need of women." A man said (to the Prophet) "Please marry her to me." The Prophet (ﷺ) said (to him), "Give her a garment." The man said, "I cannot afford it." The Prophet said, "Give her anything, even if it were an iron ring." The man apologized again. The Prophet then asked him, "What do you know by heart of the Qur'an?" He replied, "I know such-andsuch portion of the Qur'an (by heart)." The Prophet (ﷺ) said, "Then I marry her to you for that much of the Qur'an which you know by heart}}
\hadithdefcmd{bukhari}{5030}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ امْرَأَةً، جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ جِئْتُ لأَهَبَ لَكَ نَفْسِي فَنَظَرَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَعَّدَ النَّظَرَ إِلَيْهَا وَصَوَّبَهُ ثُمَّ طَأْطَأَ رَأْسَهُ، فَلَمَّا رَأَتِ الْمَرْأَةُ أَنَّهُ لَمْ يَقْضِ فِيهَا شَيْئًا جَلَسَتْ، فَقَامَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ يَا رَسُولَ اللَّهِ إِنْ لَمْ يَكُنْ لَكَ بِهَا حَاجَةٌ فَزَوِّجْنِيهَا‏.‏ فَقَالَ ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ ‏"‏‏.‏ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ اذْهَبْ إِلَى أَهْلِكَ فَانْظُرْ هَلْ تَجِدُ شَيْئًا ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا وَجَدْتُ شَيْئًا‏.‏ قَالَ ‏"‏ انْظُرْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ وَلاَ خَاتَمًا مِنْ حَدِيدٍ وَلَكِنْ هَذَا إِزَارِي ـ قَالَ سَهْلٌ مَا لَهُ رِدَاءٌ ـ فَلَهَا نِصْفُهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَصْنَعُ بِإِزَارِكَ إِنْ لَبِسْتَهُ لَمْ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ وَإِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ شَىْءٌ ‏"‏‏.‏ فَجَلَسَ الرَّجُلُ حَتَّى طَالَ مَجْلِسُهُ ثُمَّ قَامَ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مُوَلِّيًا فَأَمَرَ بِهِ فَدُعِيَ فَلَمَّا جَاءَ قَالَ ‏"‏ مَاذَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏ قَالَ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا وَسُورَةُ كَذَا عَدَّهَا قَالَ ‏"‏ أَتَقْرَؤُهُنَّ عَنْ ظَهْرِ قَلْبِكَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ اذْهَبْ فَقَدْ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏‏.‏\hadithno{5030}\hadithtrans{Narrated Sahl bin Sa`d:A lady came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I have come to you to offer myself to you." He raised his eyes and looked at her and then lowered his head. When the lady saw that he did not make any decision, she sat down. On that, a man from his companions got up and said. "O Allah's Apostle! If you are not in need of this woman, then marry her to me." Allah's Messenger (ﷺ) said, "Do you have anything to offer her?" He replied. "No, by Allah, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said to him, "Go to your family and see if you can find something.' The man went and returned, saying, "No, by Allah, O Allah's Messenger (ﷺ)! I have not found anything." The Prophet (ﷺ) said, "Try to find something, even if it is an iron ring.'' He went again and returned, saying, "No, by Allah, O Allah's Messenger (ﷺ), not even an iron ring, but I have this waist sheet of mine." The man had no upper garment, so he intended to give her, half his waist sheet. So Allah's Messenger (ﷺ) said, ''What would she do with your waist sheet? If you wear it, she will have nothing of it over her body, and if she wears it, you will have nothing over your body." So that man sat for a long period and then got up, and Allah's Messenger (ﷺ) saw him going away, so he ordered somebody to call him. When he came, the Prophet (ﷺ) asked him, " How much of the Qur'an do you know?" He replied, "I know such Surat and such Surat and such Surat," and went on counting it, The Prophet (ﷺ) asked him, "Can you recite it by heart?" he replied, "Yes." The Prophet (ﷺ) said, "Go, I have married this lady to you for the amount of the Qur'an you know by heart}}
\hadithdefcmd{bukhari}{5031}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلُ صَاحِبِ الْقُرْآنِ كَمَثَلِ صَاحِبِ الإِبِلِ الْمُعَقَّلَةِ إِنْ عَاهَدَ عَلَيْهَا أَمْسَكَهَا وَإِنْ أَطْلَقَهَا ذَهَبَتْ ‏"‏‏.‏\hadithno{5031}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "The example of the person who knows the Qur'an by heart is like the owner of tied camels. If he keeps them tied, he will control them, but if he releases them, they will run away}}
\hadithdefcmd{bukhari}{5032}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بِئْسَ مَا لأَحَدِهِمْ أَنْ يَقُولَ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ بَلْ نُسِّيَ، وَاسْتَذْكِرُوا الْقُرْآنَ فَإِنَّهُ أَشَدُّ تَفَصِّيًا مِنْ صُدُورِ الرِّجَالِ مِنَ النَّعَمِ ‏"‏‏.‏\hadithno{5032}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "It is a bad thing that some of you say, 'I have forgotten such-and-such verse of the Qur'an,' for indeed, he has been caused (by Allah) to forget it. So you must keep on reciting the Qur'an because it escapes from the hearts of men faster than camel do}}
\hadithdefcmd{bukhari}{5032p2}{حَدَّثَنَا عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، مِثْلَهُ‏.‏ تَابَعَهُ بِشْرٌ عَنِ ابْنِ الْمُبَارَكِ، عَنْ شُعْبَةَ،‏.‏ وَتَابَعَهُ ابْنُ جُرَيْجٍ عَنْ عَبْدَةَ، عَنْ شَقِيقٍ، سَمِعْتُ عَبْدَ اللَّهِ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{5032.2}\hadithtrans{Narrated `Abdullah:I heard the Prophet (ﷺ) saying... (as above, no)}}
\hadithdefcmd{bukhari}{5033}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَاهَدُوا الْقُرْآنَ فَوَالَّذِي نَفْسِي بِيَدِهِ لَهُوَ أَشَدُّ تَفَصِّيًا مِنَ الإِبِلِ فِي عُقُلِهَا ‏"‏‏.‏\hadithno{5033}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "Commit yourself to the Qur'an, for by Him in whose Hand is my soul, it is surely more prone to break away than a camel in its bind}}
\hadithdefcmd{bukhari}{5034}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَبُو إِيَاسٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ وَهْوَ يَقْرَأُ عَلَى رَاحِلَتِهِ سُورَةَ الْفَتْحِ‏.‏\hadithno{5034}\hadithtrans{Narrated `Abdullah bin Mughaffal:I saw Allah's Messenger (ﷺ) reciting Surat-al-Fath on his she-camel on the day of the Conquest of Mecca}}
\hadithdefcmd{bukhari}{5035}{حَدَّثَنِي مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ إِنَّ الَّذِي تَدْعُونَهُ الْمُفَصَّلَ هُوَ الْمُحْكَمُ، قَالَ وَقَالَ ابْنُ عَبَّاسٍ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا ابْنُ عَشْرِ سِنِينَ وَقَدْ قَرَأْتُ الْمُحْكَمَ‏.‏\hadithno{5035}\hadithtrans{Narrated Sa`id bin Jubair:Those Suras which you people call the Mufassal, are the Muhkam. And Ibn `Abbas said, "Allah's Apostle died when I was a boy of ten years, and I had learnt the Muhkam (of the Qur'an)}}
\hadithdefcmd{bukhari}{5036}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ جَمَعْتُ الْمُحْكَمَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ وَمَا الْمُحْكَمُ قَالَ الْمُفَصَّلُ‏.‏\hadithno{5036}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Abbas said, "I have learnt all the Muhkam Suras during the life time of Allah's Messenger (ﷺ)." I said to him, 'What is meant by the Muhkam?" He replied, "The Mufassal}}
\hadithdefcmd{bukhari}{5037}{حَدَّثَنَا رَبِيعُ بْنُ يَحْيَى، حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا هِشَامٌ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يَقْرَأُ فِي الْمَسْجِدِ فَقَالَ ‏ "‏ يَرْحَمُهُ اللَّهُ لَقَدْ أَذْكَرَنِي كَذَا وَكَذَا آيَةً مِنْ سُورَةِ كَذَا ‏"‏‏.‏\hadithno{5037}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) heard a man reciting the Qur'an in the mosque and said, "May Allah bestow His Mercy on him, as he has reminded me of such-and-such Verses of such a Surah}}
\hadithdefcmd{bukhari}{5037p2}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، حَدَّثَنَا عِيسَى، عَنْ هِشَامٍ، وَقَالَ، أَسْقَطْتُهُنَّ مِنْ سُورَةِ كَذَا‏.‏ تَابَعَهُ عَلِيُّ بْنُ مُسْهِرٍ وَعَبْدَةُ عَنْ هِشَامٍ‏.‏\hadithno{5037.2}\hadithtrans{Narrated Hisham:(The same Hadith as 6.556, adding): which I missed (modifying the Verses)}}
\hadithdefcmd{bukhari}{5038}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يَقْرَأُ فِي سُورَةٍ بِاللَّيْلِ فَقَالَ ‏ "‏ يَرْحَمُهُ اللَّهُ لَقَدْ أَذْكَرَنِي كَذَا وَكَذَا آيَةً كُنْتُ أُنْسِيتُهَا مِنْ سُورَةِ كَذَا وَكَذَا ‏"‏‏.‏\hadithno{5038}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) heard a man reciting the Qur'an at night, and said, "May Allah bestow His Mercy on him, as he has reminded me of such-and-such Verses of such-and-such Suras, which I was caused to forget}}
\hadithdefcmd{bukhari}{5039}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا لأَحَدِهِمْ يَقُولُ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ‏.‏ بَلْ هُوَ نُسِّيَ ‏"‏‏.‏\hadithno{5039}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Why does anyone of the people say, 'I have forgotten such-and-such Verses (of the Qur'an)?' He, in fact, is caused (by Allah) to forget}}
\hadithdefcmd{bukhari}{5040}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنْ عَلْقَمَةَ، وَعَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الآيَتَانِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ مَنْ قَرَأَ بِهِمَا فِي لَيْلَةٍ كَفَتَاهُ ‏"‏‏.‏\hadithno{5040}\hadithtrans{Narrated Abu Mas`ud al-Ansari:The Prophet (ﷺ) said, "If one recites the last two verses of Surat al-Baqarah at night, it is sufficient for him (for that night)}}
\hadithdefcmd{bukhari}{5041}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ حَدِيثِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَعَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّهُمَا سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمِ بْنِ حِزَامٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَمَعْتُ لِقِرَاءَتِهِ فَإِذَا هُوَ يَقْرَؤُهَا عَلَى حُرُوفٍ كَثِيرَةٍ لَمْ يُقْرِئْنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ فَانْتَظَرْتُهُ حَتَّى سَلَّمَ فَلَبَبْتُهُ فَقُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَأُ قَالَ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَقُلْتُ لَهُ كَذَبْتَ فَوَاللَّهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَهُوَ أَقْرَأَنِي هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ، فَانْطَلَقْتُ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَقُودُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى حُرُوفٍ لَمْ تُقْرِئْنِيهَا وَإِنَّكَ أَقْرَأْتَنِي سُورَةَ الْفُرْقَانِ‏.‏ فَقَالَ ‏"‏ يَا هِشَامُ اقْرَأْهَا ‏"‏‏.‏ فَقَرَأَهَا الْقِرَاءَةَ الَّتِي سَمِعْتُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏‏.‏ فَقَرَأْتُهَا الَّتِي أَقْرَأَنِيهَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏‏.‏\hadithno{5041}\hadithtrans{Narrated `Umar bin Khattab:I heard Hisham bin Hakim bin Hizam reciting Surat-al-Furqan during the lifetime of Allah's Messenger (ﷺ), and I listened to his recitation and noticed that he recited it in several ways which Allah's Messenger (ﷺ) had not taught me. So I was on the point of attacking him in the prayer, but I waited till he finished his prayer, and then I seized him by the collar and said, "Who taught you this Surah which I have heard you reciting?" He replied, "Allah's Messenger (ﷺ) taught it to me." I said, "You are telling a lie; By Allah! Allah's Messenger (ﷺ) taught me (in a different way) this very Surah which I have heard you reciting." So I took him, leading him to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! I heard this person reciting Surat-al-Furqan in a way that you did not teach me, and you have taught me Surat-al-Furqan." The Prophet said, "O Hisham, recite!" So he recited in the same way as I heard him recite it before. On that Allah's Messenger (ﷺ) said, "It was revealed to be recited in this way." Then Allah's Messenger (ﷺ) said, "Recite, O `Umar!" So I recited it as he had taught me. Allah's Messenger (ﷺ) then said, "It was revealed to be recited in this way." Allah" Apostle added, "The Qur'an has been revealed to be recited in several different ways, so recite of it that which is easier for you}}
\hadithdefcmd{bukhari}{5042}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم قَارِئًا يَقْرَأُ مِنَ اللَّيْلِ فِي الْمَسْجِدِ فَقَالَ ‏ "‏ يَرْحَمُهُ اللَّهُ لَقَدْ أَذْكَرَنِي كَذَا وَكَذَا آيَةً، أَسْقَطْتُهَا مِنْ سُورَةِ كَذَا وَكَذَا ‏"‏‏.‏\hadithno{5042}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) heard a reciter reciting, the Qur'an in the mosque at night. The Prophet (ﷺ) said, "May Allah bestow His Mercy on him, as he has remind ed me of such-and-such Verses of such and-such Suras, which I missed}}
\hadithdefcmd{bukhari}{5043}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا وَاصِلٌ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ غَدَوْنَا عَلَى عَبْدِ اللَّهِ فَقَالَ رَجُلٌ قَرَأْتُ الْمُفَصَّلَ الْبَارِحَةَ‏.‏ فَقَالَ هَذًّا كَهَذِّ الشِّعْرِ، إِنَّا قَدْ سَمِعْنَا الْقِرَاءَةَ وَإِنِّي لأَحْفَظُ الْقُرَنَاءَ الَّتِي كَانَ يَقْرَأُ بِهِنَّ النَّبِيُّ صلى الله عليه وسلم ثَمَانِيَ عَشْرَةَ سُورَةً مِنَ الْمُفَصَّلِ وَسُورَتَيْنِ مِنْ آلِ حم‏.‏\hadithno{5043}\hadithtrans{Narrated Abu Wail:We went to `Abdullah in the morning and a man said, "Yesterday I recited all the Mufassal Suras." On that `Abdullah said, "That is very quick, and we have the (Prophet's) recitation, and I remember very well the recitation of those Suras which the Prophet (ﷺ) used to recite, and they were eighteen Suras from the Mufassal, and two Suras from the Suras that start with Ha Mim}}
\hadithdefcmd{bukhari}{5044}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ فِي قَوْلِهِ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ‏\}‏ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا نَزَلَ جِبْرِيلُ بِالْوَحْىِ وَكَانَ مِمَّا يُحَرِّكُ بِهِ لِسَانَهُ وَشَفَتَيْهِ فَيَشْتَدُّ عَلَيْهِ وَكَانَ يُعْرَفُ مِنْهُ، فَأَنْزَلَ اللَّهُ الآيَةَ الَّتِي فِي ‏\{‏لاَ أُقْسِمُ بِيَوْمِ الْقِيَامَةِ‏\}‏ ‏\{‏لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ * إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ * فَإِذَا قَرَأْنَاهُ فَاتَّبِعْ قُرْآنَهُ‏\}‏ فَإِذَا أَنْزَلْنَاهُ فَاسْتَمِعْ ‏\{‏ثُمَّ إِنَّ عَلَيْنَا بَيَانَهُ‏\}‏ قَالَ إِنَّ عَلَيْنَا أَنْ نُبَيِّنَهُ بِلِسَانِكَ‏.‏ قَالَ وَكَانَ إِذَا أَتَاهُ جِبْرِيلُ أَطْرَقَ، فَإِذَا ذَهَبَ قَرَأَهُ كَمَا وَعَدَهُ اللَّهُ‏.‏\hadithno{5044}\hadithtrans{Narrated Ibn `Abbas:Regarding His (Allah's) Statement:-- 'Move not your tongue concerning (the Qur'an) to make haste therewith.' (75.16) And whenever Gabriel descended to Allah's Messenger (ﷺ) with the Divine Inspiration, Allah's Messenger (ﷺ) used to move his tongue and lips, and that used to be hard for him, and one could easily recognize that he was being inspired Divinely. So Allah revealed the Verse which occurs in the Surah starting with "I do swear by the Day of Resurrection.' (75.1) i.e. 'Move not your tongue concerning (the Qur'an) to make haste then with. It is for Us to collect it (in your mind) (O Muhammad) an give you the ability to recite it 'by heart.' (75.16-17) which means: It is for us to collect it (in your mind) and give you the ability to recite it by heart. And when We have recited it to you (O Muhammad) through Gabriel then follow you its recital. (75.18) means: 'When We reveal it (the Qur'an) to you, Listen to it.' for then: It is for Us to explain it and make it clear to you' (75.19) i.e. It is up to Us to explain it through your tongue. So, when Gabriel came to him, Allah's Messenger (ﷺ) would listen to him attentively, and as soon as Gabriel left, he would recite the Revelations, as Allah had promised him}}
\hadithdefcmd{bukhari}{5045}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ الأَزْدِيُّ، حَدَّثَنَا قَتَادَةُ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنْ قِرَاءَةِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ كَانَ يَمُدُّ مَدًّا‏.‏\hadithno{5045}\hadithtrans{Narrated Qatada:I asked Anas bin Malik about the recitation of the Prophet. He said, "He used to pray long (certain sounds) very much}}
\hadithdefcmd{bukhari}{5046}{حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ سُئِلَ أَنَسٌ كَيْفَ كَانَتْ قِرَاءَةُ النَّبِيِّ صلى الله عليه وسلم‏.‏ فَقَالَ كَانَتْ مَدًّا‏.‏ ثُمَّ قَرَأَ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ، يَمُدُّ بِبِسْمِ اللَّهِ، وَيَمُدُّ بِالرَّحْمَنِ، وَيَمُدُّ بِالرَّحِيمِ‏.‏\hadithno{5046}\hadithtrans{Narrated Qatada:Anas was asked, "How was the recitation (of the Qur'an) of the Prophet?' He replied, "It was characterized by the prolongation of certain sounds." He then recited: In the Name of Allah, the Most Beneficent, the Most Merciful prolonging the pronunciation of 'In the Name of Allah, 'the most Beneficent,' and 'the Most Merciful}}
\hadithdefcmd{bukhari}{5047}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو إِيَاسٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ وَهْوَ عَلَى نَاقَتِهِ ـ أَوْ جَمَلِهِ ـ وَهْىَ تَسِيرُ بِهِ وَهْوَ يَقْرَأُ سُورَةَ الْفَتْحِ أَوْ مِنْ سُورَةِ الْفَتْحِ قِرَاءَةً لَيِّنَةً يَقْرَأُ وَهْوَ يُرَجِّعُ‏.‏\hadithno{5047}\hadithtrans{Narrated `Abdullah bin Mughaffal:I saw the Prophet (ﷺ) reciting (Qur'an) while he was riding on his she camel or camel which was moving, carrying him. He was reciting Surat Fath or part of Surat Fath very softly and in an Attractive vibrating tone}}
\hadithdefcmd{bukhari}{5048}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ أَبُو بَكْرٍ، حَدَّثَنَا أَبُو يَحْيَى الْحِمَّانِيُّ، حَدَّثَنَا بُرَيْدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا أَبَا مُوسَى لَقَدْ أُوتِيتَ مِزْمَارًا مِنْ مَزَامِيرِ آلِ دَاوُدَ ‏"‏‏.‏\hadithno{5048}\hadithtrans{Narrated Abu Musa:That the Prophet (ﷺ) said to him' "O Abu Musa! You have been given one of the mazamir (sweet melodious voices) of the family of David}}
\hadithdefcmd{bukhari}{5049}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، رضى الله عنه قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ الْقُرْآنَ ‏"‏‏.‏ قُلْتُ آقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ إِنِّي أُحِبُّ أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏‏.‏\hadithno{5049}\hadithtrans{Narrated `Abdullah:That the Prophet (ﷺ) said to him, "Recite the Qur'an to me." `Abdullah said, "Shall I recite (the Qur'an) to you while it has been revealed to you?" He said, "I like to hear it from others}}
\hadithdefcmd{bukhari}{5050}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ آقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَقَرَأْتُ سُورَةَ النِّسَاءِ حَتَّى أَتَيْتُ إِلَى هَذِهِ الآيَةِ ‏\{‏فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَى هَؤُلاَءِ شَهِيدًا‏\}‏ قَالَ ‏"‏ حَسْبُكَ الآنَ ‏"‏‏.‏ فَالْتَفَتُّ إِلَيْهِ فَإِذَا عَيْنَاهُ تَذْرِفَانِ‏.‏\hadithno{5050}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) said to me, "Recite (the Qur'an) to me." I said, "O Allah's Messenger (ﷺ) Shall I recite (the Qur'an) to you while it has been revealed to you?" He said, "Yes." So I recited Surat-An-Nisa' (The Women), but when I recited the Verse: 'How (will it be) then when We bring from each nation a witness and We bring you (O Muhammad) as a witness against these people.' (4.41) He said, "Enough for the present," I looked at him and behold! His eyes were overflowing with tears}}
\hadithdefcmd{bukhari}{5051}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ لِي ابْنُ شُبْرُمَةَ نَظَرْتُ كَمْ يَكْفِي الرَّجُلَ مِنَ الْقُرْآنِ فَلَمْ أَجِدْ سُورَةً أَقَلَّ مِنْ ثَلاَثِ آيَاتٍ، فَقُلْتُ لاَ يَنْبَغِي لأَحَدٍ أَنْ يَقْرَأَ أَقَلَّ مِنْ ثَلاَثِ آيَاتٍ‏.‏\hadithno{5051}\hadithtrans{Narrated Sufyan: Ibn Shubruma said, "I wanted to see how much of the Qur'an can be enough (to recite in prayer) and I could not find a Surah containing less than three Verses, therefore I said to myself), "One ought not to recite less than three (Quranic) Verses (in prayer)}}
\hadithdefcmd{bukhari}{5051p2}{قَالَ عَلِيٌّ قَالَ سُفْيَانُ أَخْبَرَنَا مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، أَخْبَرَهُ عَلْقَمَةُ، عَنْ أَبِي مَسْعُودٍ، وَلَقِيتُهُ، وَهْوَ يَطُوفُ بِالْبَيْتِ فَذَكَرَ قَوْلَ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ مَنْ قَرَأَ بِالآيَتَيْنِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي لَيْلَةٍ كَفَتَاهُ ‏"‏‏.‏\hadithno{5051.2}\hadithtrans{Narrated Abu Mas'ud:The Prophet (ﷺ) said, "If somebody recites the last two Verses of Surat al-Baqara at night, it will be sufficient for him}}
\hadithdefcmd{bukhari}{5052}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ أَنْكَحَنِي أَبِي امْرَأَةً ذَاتَ حَسَبٍ فَكَانَ يَتَعَاهَدُ كَنَّتَهُ فَيَسْأَلُهَا عَنْ بَعْلِهَا فَتَقُولُ نِعْمَ الرَّجُلُ مِنْ رَجُلٍ لَمْ يَطَأْ لَنَا فِرَاشًا وَلَمْ يُفَتِّشْ لَنَا كَنَفًا مُذْ أَتَيْنَاهُ فَلَمَّا طَالَ ذَلِكَ عَلَيْهِ ذَكَرَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ الْقَنِي بِهِ ‏"‏‏.‏ فَلَقِيتُهُ بَعْدُ فَقَالَ ‏"‏ كَيْفَ تَصُومُ ‏"‏‏.‏ قَالَ كُلَّ يَوْمٍ‏.‏ قَالَ ‏"‏ وَكَيْفَ تَخْتِمُ ‏"‏‏.‏ قَالَ كُلَّ لَيْلَةً‏.‏ قَالَ ‏"‏ صُمْ فِي كُلِّ شَهْرٍ ثَلاَثَةً وَاقْرَإِ الْقُرْآنَ فِي كُلِّ شَهْرٍ ‏"‏‏.‏ قَالَ قُلْتُ أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ فِي الْجُمُعَةِ ‏"‏‏.‏ قُلْتُ أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ أَفْطِرْ يَوْمَيْنِ وَصُمْ يَوْمًا ‏"‏‏.‏ قَالَ قُلْتُ أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ‏.‏ قَالَ ‏"‏ صُمْ أَفْضَلَ الصَّوْمِ صَوْمِ دَاوُدَ صِيَامَ يَوْمٍ وَإِفْطَارَ يَوْمٍ وَاقْرَأْ فِي كُلِّ سَبْعِ لَيَالٍ مَرَّةً ‏"‏‏.‏ فَلَيْتَنِي قَبِلْتُ رُخْصَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَاكَ أَنِّي كَبِرْتُ وَضَعُفْتُ فَكَانَ يَقْرَأُ عَلَى بَعْضِ أَهْلِهِ السُّبْعَ مِنَ الْقُرْآنِ بِالنَّهَارِ وَالَّذِي يَقْرَؤُهُ يَعْرِضُهُ مِنَ النَّهَارِ لِيَكُونَ أَخَفَّ عَلَيْهِ بِاللَّيْلِ وَإِذَا أَرَادَ أَنْ يَتَقَوَّى أَفْطَرَ أَيَّامًا وَأَحْصَى وَصَامَ مِثْلَهُنَّ كَرَاهِيةَ أَنْ يَتْرُكَ شَيْئًا فَارَقَ النَّبِيَّ صلى الله عليه وسلم عَلَيْهِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ بَعْضُهُمْ فِي ثَلاَثٍ وَفِي خَمْسٍ وَأَكْثَرُهُمْ عَلَى سَبْعٍ‏.‏\hadithno{5052}\hadithtrans{Narrated `Abdullah bin `Amr bin Al `As:My father got me married to a lady of a noble family, and often used to ask my wife about me, and she used to reply, "What a wonderful man he is! He never comes to my bed, nor has he approached me since he married me." When this state continued for a long period, my father told the story to the Prophet who said to my father, "Let me meet him." Then I met him and he asked me, "How do you fast?" I replied, "I fast daily," He asked, "How long does it take you to finish the recitation of the whole Qur'an?" I replied, "I finish it every night." On that he said, "Fast for three days every month and recite the Qur'an (and finish it) in one month." I said, "But I have power to do more than that." He said, "Then fast for three days per week." I said, "i have the power to do more than that." He said, "Therefore, fast the most superior type of fasting, (that is, the fasting of (prophet) David who used to fast every alternate day; and finish the recitation of the whole Qur'an In seven days." I wish I had accepted the permission of Allah's Messenger (ﷺ) as I have become a weak old man. It is said that `Abdullah used to recite one-seventh of the Qur'an during the day-time to some of his family members, for he used to check his memorization of what he would recite at night during the daytime so that it would be easier for him to read at night. And whenever he wanted to gain some strength, he used to give up fasting for some days and count those days to fast for a similar period, for he disliked to leave those things which he used to do during the lifetime of the Prophet}}
\hadithdefcmd{bukhari}{5053}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فِي كَمْ تَقْرَأُ الْقُرْآنَ ‏"‏‏.‏\hadithno{5053}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) asked me, "How long does it take you to finish the recitation of the whole Qur'an?}}
\hadithdefcmd{bukhari}{5054}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ شَيْبَانَ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى بَنِي زُهْرَةَ عَنْ أَبِي سَلَمَةَ ـ قَالَ وَأَحْسِبُنِي قَالَ ـ سَمِعْتُ أَنَا مِنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ الْقُرْآنَ فِي شَهْرٍ ‏"‏‏.‏ قُلْتُ إِنِّي أَجِدُ قُوَّةً حَتَّى قَالَ ‏"‏ فَاقْرَأْهُ فِي سَبْعٍ وَلاَ تَزِدْ عَلَى ذَلِكَ ‏"‏‏.‏\hadithno{5054}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) said to me, "Recite the whole Qur'an in one month's time." I said, "But I have power (to do more than that)." Allah's Messenger (ﷺ) said, "Then finish the recitation of the Qur'an in seven days, and do not finish it in less than this period}}
\hadithdefcmd{bukhari}{5055}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ يَحْيَى بَعْضُ الْحَدِيثِ عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ لِي النَّبِيُّ صلى الله عليه وسلم‏.‏ ـ حَدَّثَنَا مُسَدَّدٌ عَنْ يَحْيَى عَنْ سُفْيَانَ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ عَنْ عَبِيدَةَ عَنْ عَبْدِ اللَّهِ قَالَ الأَعْمَشُ وَبَعْضُ الْحَدِيثِ حَدَّثَنِي عَمْرُو بْنُ مُرَّةَ عَنْ إِبْرَاهِيمَ وَعَنْ أَبِيهِ عَنْ أَبِي الضُّحَى عَنْ عَبْدِ اللَّهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ ‏"‏‏.‏ قَالَ قُلْتُ أَقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ إِنِّي أَشْتَهِي أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏‏.‏ قَالَ فَقَرَأْتُ النِّسَاءَ حَتَّى إِذَا بَلَغْتُ ‏\{‏فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَى هَؤُلاَءِ شَهِيدًا‏\}‏‏.‏ قَالَ لِي ‏"‏ كُفَّ ـ أَوْ أَمْسِكْ ـ ‏"‏‏.‏ فَرَأَيْتُ عَيْنَيْهِ تَذْرِفَانِ‏.‏\hadithno{5055}\hadithtrans{Narrated `Abdullah (bin Mas`ud):Allah's Messenger (ﷺ) said (to me), "Recite the Qur'an to me." I said, "Shall I recite (it) to you while it has been revealed to you?" He said, "I like to hear it from another person." So I recited Surat An-Nisa (The Women) till I reached the Verse: 'How (will it be) then when We bring from each nation a witness, and We bring you (O Muhammad) as a witness against these people.' (4.41) Then he said to me, "Stop!" Thereupon I saw his eyes overflowing with tears}}
\hadithdefcmd{bukhari}{5056}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ السَّلْمَانِيِّ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ ‏"‏‏.‏ قُلْتُ أَقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ إِنِّي أُحِبُّ أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏‏.‏\hadithno{5056}\hadithtrans{Narrated `Abdullah bin Masud:The Prophet (ﷺ) said to me, "Recite Qur'an to me." I said to him. "Shall I recite (it) to you while it has been revealed to you?" He said, "I like to hear it from another person}}
\hadithdefcmd{bukhari}{5057}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، عَنْ خَيْثَمَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ عَلِيٌّ رضى الله عنه سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَأْتِي فِي آخِرِ الزَّمَانِ قَوْمٌ حُدَثَاءُ الأَسْنَانِ، سُفَهَاءُ الأَحْلاَمِ، يَقُولُونَ مِنْ خَيْرِ قَوْلِ الْبَرِيَّةِ، يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، لاَ يُجَاوِزُ إِيمَانُهُمْ حَنَاجِرَهُمْ، فَأَيْنَمَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ، فَإِنَّ قَتْلَهُمْ أَجْرٌ لِمَنْ قَتَلَهُمْ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{5057}\hadithtrans{Narrated `Ali:I heard the Prophet (ﷺ) saying, "In the last days (of the world) there will appear young people with foolish thoughts and ideas. They will give good talks, but they will go out of Islam as an arrow goes out of its game, their faith will not exceed their throats. So, wherever you find them, kill them, for there will be a reward for their killers on the Day of Resurrection}}
\hadithdefcmd{bukhari}{5058}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَخْرُجُ فِيكُمْ قَوْمٌ تَحْقِرُونَ صَلاَتَكُمْ مَعَ صَلاَتِهِمْ، وَصِيَامَكُمْ مَعَ صِيَامِهِمْ، وَعَمَلَكُمْ مَعَ عَمَلِهِمْ، وَيَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ، يَمْرُقُونَ مِنَ الدِّينَ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، يَنْظُرُ فِي النَّصْلِ فَلاَ يَرَى شَيْئًا، وَيَنْظُرُ فِي الْقِدْحِ فَلاَ يَرَى شَيْئًا، وَيَنْظُرُ فِي الرِّيشِ فَلاَ يَرَى شَيْئًا، وَيَتَمَارَى فِي الْفُوقِ ‏"‏‏.‏\hadithno{5058}\hadithtrans{Narrated Abu Sa`id Al-Khudri:I heard Allah's Messenger (ﷺ) saying, "There will appear some people among you whose prayer will make you look down upon yours, and whose fasting will make you look down upon yours, but they will recite the Qur'an which will not exceed their throats (they will not act on it) and they will go out of Islam as an arrow goes out through the game whereupon the archer would examine the arrowhead but see nothing, and look at the unfeathered arrow but see nothing, and look at the arrow feathers but see nothing, and finally he suspects to find something in the lower part of the arrow}}
\hadithdefcmd{bukhari}{5059}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُؤْمِنُ الَّذِي يَقْرَأُ الْقُرْآنَ وَيَعْمَلُ بِهِ كَالأُتْرُجَّةِ، طَعْمُهَا طَيِّبٌ وَرِيحُهَا طَيِّبٌ، وَالْمُؤْمِنُ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ وَيَعْمَلُ بِهِ كَالتَّمْرَةِ، طَعْمُهَا طَيِّبٌ وَلاَ رِيحَ لَهَا، وَمَثَلُ الْمُنَافِقِ الَّذِي يَقْرَأُ الْقُرْآنَ كَالرَّيْحَانَةِ، رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ، وَمَثَلُ الْمُنَافِقِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَالْحَنْظَلَةِ، طَعْمُهَا مُرٌّ ـ أَوْ خَبِيثٌ ـ وَرِيحُهَا مُرٌّ ‏"‏‏.‏\hadithno{5059}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The example of a believer who recites the Qur'an and acts on it, like a citron which tastes nice and smells nice. And the example of a believer who does not recite the Qur'an but acts on it, is like a date which tastes good but has no smell. And the example of a hypocrite who recites the Qur'an is like a Raihana (sweet basil) which smells good but tastes bitter And the example of a hypocrite who does not recite the Qur'an is like a colocynth which tastes bitter and has a bad smell}}
\hadithdefcmd{bukhari}{5060}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ جُنْدَبِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اقْرَءُوا الْقُرْآنَ مَا ائْتَلَفَتْ قُلُوبُكُمْ، فَإِذَا اخْتَلَفْتُمْ فَقُومُوا عَنْهُ ‏"‏‏.‏\hadithno{5060}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Recite (and study) the Qur'an as long as you agree about its interpretation, but if you have any difference of opinion (as regards to its interpretation and meaning) then you should stop reciting it (for the time being)}}
\hadithdefcmd{bukhari}{5061}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سَلاَّمُ بْنُ أَبِي مُطِيعٍ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ جُنْدَبٍ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اقْرَءُوا الْقُرْآنَ مَا ائْتَلَفَتْ عَلَيْهِ قُلُوبُكُمْ فَإِذَا اخْتَلَفْتُمْ فَقُومُوا عَنْهُ ‏"‏‏.‏ تَابَعَهُ الْحَارِثُ بْنُ عُبَيْدٍ وَسَعِيدُ بْنُ زَيْدٍ عَنْ أَبِي عِمْرَانَ وَلَمْ يَرْفَعْهُ حَمَّادُ بْنُ سَلَمَةَ وَأَبَانُ‏.‏ وَقَالَ غُنْدَرٌ عَنْ شُعْبَةَ عَنْ أَبِي عِمْرَانَ سَمِعْتُ جُنْدَبًا قَوْلَهُ‏.‏ وَقَالَ ابْنُ عَوْنٍ عَنْ أَبِي عِمْرَانَ عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ عَنْ عُمَرَ قَوْلَهُ، وَجُنْدَبٌ أَصَحُّ وَأَكْثَرُ‏.‏\hadithno{5061}\hadithtrans{Narrated Jundub:The Prophet (ﷺ) said, "Recite (and study) the Qur'an as long as you agree about its interpretation, but when you have any difference of opinion (as regards its interpretation and meaning) then you should stop reciting it (for the time being)}}
\hadithdefcmd{bukhari}{5062}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنِ النَّزَّالِ بْنِ سَبْرَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَجُلاً، يَقْرَأُ آيَةً، سَمِعَ النَّبِيَّ صلى الله عليه وسلم خِلاَفَهَا، فَأَخَذْتُ بِيَدِهِ فَانْطَلَقْتُ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ كِلاَكُمَا مُحْسِنٌ فَاقْرَآ ـ أَكْبَرُ عِلْمِي قَالَ ـ فَإِنَّ مَنْ كَانَ قَبْلَكُمُ اخْتَلَفُوا فَأَهْلَكَهُمْ ‏"‏‏.‏\hadithno{5062}\hadithtrans{Narrated `Abdullah:That he heard a man reciting a Quranic Verse which he had heard the Prophet (ﷺ) reciting in a different way. So he took that man to the Prophet (and told him the story). The Prophet (ﷺ) said, "Both of you are reciting in a correct way, so carry on reciting." The Prophet (ﷺ) further added, "The nations which were before you were destroyed (by Allah) because they differed}}
